import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class GmailResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class UsersResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class DraftsResource(googleapiclient.discovery.Resource):
            def create(
                self, *, userId: str, body: Draft = ..., **kwargs: typing.Any
            ) -> DraftHttpRequest: ...
            def delete(
                self, *, userId: str, id: str, **kwargs: typing.Any
            ) -> googleapiclient.http.HttpRequest: ...
            def get(
                self,
                *,
                userId: str,
                id: str,
                format: typing_extensions.Literal[
                    "minimal", "full", "raw", "metadata"
                ] = ...,
                **kwargs: typing.Any
            ) -> DraftHttpRequest: ...
            def list(
                self,
                *,
                userId: str,
                includeSpamTrash: bool = ...,
                maxResults: int = ...,
                pageToken: str = ...,
                q: str = ...,
                **kwargs: typing.Any
            ) -> ListDraftsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListDraftsResponseHttpRequest,
                previous_response: ListDraftsResponse,
            ) -> ListDraftsResponseHttpRequest | None: ...
            def send(
                self, *, userId: str, body: Draft = ..., **kwargs: typing.Any
            ) -> MessageHttpRequest: ...
            def update(
                self, *, userId: str, id: str, body: Draft = ..., **kwargs: typing.Any
            ) -> DraftHttpRequest: ...

        @typing.type_check_only
        class HistoryResource(googleapiclient.discovery.Resource):
            def list(
                self,
                *,
                userId: str,
                historyTypes: typing_extensions.Literal[
                    "messageAdded", "messageDeleted", "labelAdded", "labelRemoved"
                ]
                | _list[
                    typing_extensions.Literal[
                        "messageAdded", "messageDeleted", "labelAdded", "labelRemoved"
                    ]
                ] = ...,
                labelId: str = ...,
                maxResults: int = ...,
                pageToken: str = ...,
                startHistoryId: str = ...,
                **kwargs: typing.Any
            ) -> ListHistoryResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListHistoryResponseHttpRequest,
                previous_response: ListHistoryResponse,
            ) -> ListHistoryResponseHttpRequest | None: ...

        @typing.type_check_only
        class LabelsResource(googleapiclient.discovery.Resource):
            def create(
                self, *, userId: str, body: Label = ..., **kwargs: typing.Any
            ) -> LabelHttpRequest: ...
            def delete(
                self, *, userId: str, id: str, **kwargs: typing.Any
            ) -> googleapiclient.http.HttpRequest: ...
            def get(
                self, *, userId: str, id: str, **kwargs: typing.Any
            ) -> LabelHttpRequest: ...
            def list(
                self, *, userId: str, **kwargs: typing.Any
            ) -> ListLabelsResponseHttpRequest: ...
            def patch(
                self, *, userId: str, id: str, body: Label = ..., **kwargs: typing.Any
            ) -> LabelHttpRequest: ...
            def update(
                self, *, userId: str, id: str, body: Label = ..., **kwargs: typing.Any
            ) -> LabelHttpRequest: ...

        @typing.type_check_only
        class MessagesResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class AttachmentsResource(googleapiclient.discovery.Resource):
                def get(
                    self, *, userId: str, messageId: str, id: str, **kwargs: typing.Any
                ) -> MessagePartBodyHttpRequest: ...

            def batchDelete(
                self,
                *,
                userId: str,
                body: BatchDeleteMessagesRequest = ...,
                **kwargs: typing.Any
            ) -> googleapiclient.http.HttpRequest: ...
            def batchModify(
                self,
                *,
                userId: str,
                body: BatchModifyMessagesRequest = ...,
                **kwargs: typing.Any
            ) -> googleapiclient.http.HttpRequest: ...
            def delete(
                self, *, userId: str, id: str, **kwargs: typing.Any
            ) -> googleapiclient.http.HttpRequest: ...
            def get(
                self,
                *,
                userId: str,
                id: str,
                format: typing_extensions.Literal[
                    "minimal", "full", "raw", "metadata"
                ] = ...,
                metadataHeaders: str | _list[str] = ...,
                **kwargs: typing.Any
            ) -> MessageHttpRequest: ...
            def import_(
                self,
                *,
                userId: str,
                body: Message = ...,
                deleted: bool = ...,
                internalDateSource: typing_extensions.Literal[
                    "receivedTime", "dateHeader"
                ] = ...,
                neverMarkSpam: bool = ...,
                processForCalendar: bool = ...,
                **kwargs: typing.Any
            ) -> MessageHttpRequest: ...
            def insert(
                self,
                *,
                userId: str,
                body: Message = ...,
                deleted: bool = ...,
                internalDateSource: typing_extensions.Literal[
                    "receivedTime", "dateHeader"
                ] = ...,
                **kwargs: typing.Any
            ) -> MessageHttpRequest: ...
            def list(
                self,
                *,
                userId: str,
                includeSpamTrash: bool = ...,
                labelIds: str | _list[str] = ...,
                maxResults: int = ...,
                pageToken: str = ...,
                q: str = ...,
                **kwargs: typing.Any
            ) -> ListMessagesResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListMessagesResponseHttpRequest,
                previous_response: ListMessagesResponse,
            ) -> ListMessagesResponseHttpRequest | None: ...
            def modify(
                self,
                *,
                userId: str,
                id: str,
                body: ModifyMessageRequest = ...,
                **kwargs: typing.Any
            ) -> MessageHttpRequest: ...
            def send(
                self, *, userId: str, body: Message = ..., **kwargs: typing.Any
            ) -> MessageHttpRequest: ...
            def trash(
                self, *, userId: str, id: str, **kwargs: typing.Any
            ) -> MessageHttpRequest: ...
            def untrash(
                self, *, userId: str, id: str, **kwargs: typing.Any
            ) -> MessageHttpRequest: ...
            def attachments(self) -> AttachmentsResource: ...

        @typing.type_check_only
        class SettingsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class DelegatesResource(googleapiclient.discovery.Resource):
                def create(
                    self, *, userId: str, body: Delegate = ..., **kwargs: typing.Any
                ) -> DelegateHttpRequest: ...
                def delete(
                    self, *, userId: str, delegateEmail: str, **kwargs: typing.Any
                ) -> googleapiclient.http.HttpRequest: ...
                def get(
                    self, *, userId: str, delegateEmail: str, **kwargs: typing.Any
                ) -> DelegateHttpRequest: ...
                def list(
                    self, *, userId: str, **kwargs: typing.Any
                ) -> ListDelegatesResponseHttpRequest: ...

            @typing.type_check_only
            class FiltersResource(googleapiclient.discovery.Resource):
                def create(
                    self, *, userId: str, body: Filter = ..., **kwargs: typing.Any
                ) -> FilterHttpRequest: ...
                def delete(
                    self, *, userId: str, id: str, **kwargs: typing.Any
                ) -> googleapiclient.http.HttpRequest: ...
                def get(
                    self, *, userId: str, id: str, **kwargs: typing.Any
                ) -> FilterHttpRequest: ...
                def list(
                    self, *, userId: str, **kwargs: typing.Any
                ) -> ListFiltersResponseHttpRequest: ...

            @typing.type_check_only
            class ForwardingAddressesResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    userId: str,
                    body: ForwardingAddress = ...,
                    **kwargs: typing.Any
                ) -> ForwardingAddressHttpRequest: ...
                def delete(
                    self, *, userId: str, forwardingEmail: str, **kwargs: typing.Any
                ) -> googleapiclient.http.HttpRequest: ...
                def get(
                    self, *, userId: str, forwardingEmail: str, **kwargs: typing.Any
                ) -> ForwardingAddressHttpRequest: ...
                def list(
                    self, *, userId: str, **kwargs: typing.Any
                ) -> ListForwardingAddressesResponseHttpRequest: ...

            @typing.type_check_only
            class SendAsResource(googleapiclient.discovery.Resource):
                @typing.type_check_only
                class SmimeInfoResource(googleapiclient.discovery.Resource):
                    def delete(
                        self,
                        *,
                        userId: str,
                        sendAsEmail: str,
                        id: str,
                        **kwargs: typing.Any
                    ) -> googleapiclient.http.HttpRequest: ...
                    def get(
                        self,
                        *,
                        userId: str,
                        sendAsEmail: str,
                        id: str,
                        **kwargs: typing.Any
                    ) -> SmimeInfoHttpRequest: ...
                    def insert(
                        self,
                        *,
                        userId: str,
                        sendAsEmail: str,
                        body: SmimeInfo = ...,
                        **kwargs: typing.Any
                    ) -> SmimeInfoHttpRequest: ...
                    def list(
                        self, *, userId: str, sendAsEmail: str, **kwargs: typing.Any
                    ) -> ListSmimeInfoResponseHttpRequest: ...
                    def setDefault(
                        self,
                        *,
                        userId: str,
                        sendAsEmail: str,
                        id: str,
                        **kwargs: typing.Any
                    ) -> googleapiclient.http.HttpRequest: ...

                def create(
                    self, *, userId: str, body: SendAs = ..., **kwargs: typing.Any
                ) -> SendAsHttpRequest: ...
                def delete(
                    self, *, userId: str, sendAsEmail: str, **kwargs: typing.Any
                ) -> googleapiclient.http.HttpRequest: ...
                def get(
                    self, *, userId: str, sendAsEmail: str, **kwargs: typing.Any
                ) -> SendAsHttpRequest: ...
                def list(
                    self, *, userId: str, **kwargs: typing.Any
                ) -> ListSendAsResponseHttpRequest: ...
                def patch(
                    self,
                    *,
                    userId: str,
                    sendAsEmail: str,
                    body: SendAs = ...,
                    **kwargs: typing.Any
                ) -> SendAsHttpRequest: ...
                def update(
                    self,
                    *,
                    userId: str,
                    sendAsEmail: str,
                    body: SendAs = ...,
                    **kwargs: typing.Any
                ) -> SendAsHttpRequest: ...
                def verify(
                    self, *, userId: str, sendAsEmail: str, **kwargs: typing.Any
                ) -> googleapiclient.http.HttpRequest: ...
                def smimeInfo(self) -> SmimeInfoResource: ...

            def getAutoForwarding(
                self, *, userId: str, **kwargs: typing.Any
            ) -> AutoForwardingHttpRequest: ...
            def getImap(
                self, *, userId: str, **kwargs: typing.Any
            ) -> ImapSettingsHttpRequest: ...
            def getLanguage(
                self, *, userId: str, **kwargs: typing.Any
            ) -> LanguageSettingsHttpRequest: ...
            def getPop(
                self, *, userId: str, **kwargs: typing.Any
            ) -> PopSettingsHttpRequest: ...
            def getVacation(
                self, *, userId: str, **kwargs: typing.Any
            ) -> VacationSettingsHttpRequest: ...
            def updateAutoForwarding(
                self, *, userId: str, body: AutoForwarding = ..., **kwargs: typing.Any
            ) -> AutoForwardingHttpRequest: ...
            def updateImap(
                self, *, userId: str, body: ImapSettings = ..., **kwargs: typing.Any
            ) -> ImapSettingsHttpRequest: ...
            def updateLanguage(
                self, *, userId: str, body: LanguageSettings = ..., **kwargs: typing.Any
            ) -> LanguageSettingsHttpRequest: ...
            def updatePop(
                self, *, userId: str, body: PopSettings = ..., **kwargs: typing.Any
            ) -> PopSettingsHttpRequest: ...
            def updateVacation(
                self, *, userId: str, body: VacationSettings = ..., **kwargs: typing.Any
            ) -> VacationSettingsHttpRequest: ...
            def delegates(self) -> DelegatesResource: ...
            def filters(self) -> FiltersResource: ...
            def forwardingAddresses(self) -> ForwardingAddressesResource: ...
            def sendAs(self) -> SendAsResource: ...

        @typing.type_check_only
        class ThreadsResource(googleapiclient.discovery.Resource):
            def delete(
                self, *, userId: str, id: str, **kwargs: typing.Any
            ) -> googleapiclient.http.HttpRequest: ...
            def get(
                self,
                *,
                userId: str,
                id: str,
                format: typing_extensions.Literal["full", "metadata", "minimal"] = ...,
                metadataHeaders: str | _list[str] = ...,
                **kwargs: typing.Any
            ) -> ThreadHttpRequest: ...
            def list(
                self,
                *,
                userId: str,
                includeSpamTrash: bool = ...,
                labelIds: str | _list[str] = ...,
                maxResults: int = ...,
                pageToken: str = ...,
                q: str = ...,
                **kwargs: typing.Any
            ) -> ListThreadsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListThreadsResponseHttpRequest,
                previous_response: ListThreadsResponse,
            ) -> ListThreadsResponseHttpRequest | None: ...
            def modify(
                self,
                *,
                userId: str,
                id: str,
                body: ModifyThreadRequest = ...,
                **kwargs: typing.Any
            ) -> ThreadHttpRequest: ...
            def trash(
                self, *, userId: str, id: str, **kwargs: typing.Any
            ) -> ThreadHttpRequest: ...
            def untrash(
                self, *, userId: str, id: str, **kwargs: typing.Any
            ) -> ThreadHttpRequest: ...

        def getProfile(
            self, *, userId: str, **kwargs: typing.Any
        ) -> ProfileHttpRequest: ...
        def stop(
            self, *, userId: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def watch(
            self, *, userId: str, body: WatchRequest = ..., **kwargs: typing.Any
        ) -> WatchResponseHttpRequest: ...
        def drafts(self) -> DraftsResource: ...
        def history(self) -> HistoryResource: ...
        def labels(self) -> LabelsResource: ...
        def messages(self) -> MessagesResource: ...
        def settings(self) -> SettingsResource: ...
        def threads(self) -> ThreadsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def users(self) -> UsersResource: ...

@typing.type_check_only
class AutoForwardingHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AutoForwarding: ...

@typing.type_check_only
class DelegateHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Delegate: ...

@typing.type_check_only
class DraftHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Draft: ...

@typing.type_check_only
class FilterHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Filter: ...

@typing.type_check_only
class ForwardingAddressHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ForwardingAddress: ...

@typing.type_check_only
class ImapSettingsHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ImapSettings: ...

@typing.type_check_only
class LabelHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Label: ...

@typing.type_check_only
class LanguageSettingsHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> LanguageSettings: ...

@typing.type_check_only
class ListDelegatesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListDelegatesResponse: ...

@typing.type_check_only
class ListDraftsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListDraftsResponse: ...

@typing.type_check_only
class ListFiltersResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListFiltersResponse: ...

@typing.type_check_only
class ListForwardingAddressesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListForwardingAddressesResponse: ...

@typing.type_check_only
class ListHistoryResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListHistoryResponse: ...

@typing.type_check_only
class ListLabelsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListLabelsResponse: ...

@typing.type_check_only
class ListMessagesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListMessagesResponse: ...

@typing.type_check_only
class ListSendAsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListSendAsResponse: ...

@typing.type_check_only
class ListSmimeInfoResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListSmimeInfoResponse: ...

@typing.type_check_only
class ListThreadsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListThreadsResponse: ...

@typing.type_check_only
class MessageHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Message: ...

@typing.type_check_only
class MessagePartBodyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> MessagePartBody: ...

@typing.type_check_only
class PopSettingsHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> PopSettings: ...

@typing.type_check_only
class ProfileHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Profile: ...

@typing.type_check_only
class SendAsHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SendAs: ...

@typing.type_check_only
class SmimeInfoHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SmimeInfo: ...

@typing.type_check_only
class ThreadHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Thread: ...

@typing.type_check_only
class VacationSettingsHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> VacationSettings: ...

@typing.type_check_only
class WatchResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> WatchResponse: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class DriveLabelsResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class LabelsResource(googleapiclient.discovery.Resource):
        def get(
            self,
            *,
            name: str,
            languageCode: str = ...,
            useAdminAccess: bool = ...,
            view: typing_extensions.Literal[
                "LABEL_VIEW_BASIC", "LABEL_VIEW_FULL"
            ] = ...,
            **kwargs: typing.Any
        ) -> GoogleAppsDriveLabelsV2LabelHttpRequest: ...
        def list(
            self,
            *,
            languageCode: str = ...,
            minimumRole: typing_extensions.Literal[
                "LABEL_ROLE_UNSPECIFIED", "READER", "APPLIER", "ORGANIZER", "EDITOR"
            ] = ...,
            pageSize: int = ...,
            pageToken: str = ...,
            publishedOnly: bool = ...,
            useAdminAccess: bool = ...,
            view: typing_extensions.Literal[
                "LABEL_VIEW_BASIC", "LABEL_VIEW_FULL"
            ] = ...,
            **kwargs: typing.Any
        ) -> GoogleAppsDriveLabelsV2ListLabelsResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: GoogleAppsDriveLabelsV2ListLabelsResponseHttpRequest,
            previous_response: GoogleAppsDriveLabelsV2ListLabelsResponse,
        ) -> GoogleAppsDriveLabelsV2ListLabelsResponseHttpRequest | None: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def labels(self) -> LabelsResource: ...

@typing.type_check_only
class GoogleAppsDriveLabelsV2LabelHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleAppsDriveLabelsV2Label: ...

@typing.type_check_only
class GoogleAppsDriveLabelsV2ListLabelsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleAppsDriveLabelsV2ListLabelsResponse: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class TagManagerResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class AccountsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class ContainersResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class EnvironmentsResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    accountId: str,
                    containerId: str,
                    body: Environment = ...,
                    **kwargs: typing.Any
                ) -> EnvironmentHttpRequest: ...
                def delete(
                    self,
                    *,
                    accountId: str,
                    containerId: str,
                    environmentId: str,
                    **kwargs: typing.Any
                ) -> googleapiclient.http.HttpRequest: ...
                def get(
                    self,
                    *,
                    accountId: str,
                    containerId: str,
                    environmentId: str,
                    **kwargs: typing.Any
                ) -> EnvironmentHttpRequest: ...
                def list(
                    self, *, accountId: str, containerId: str, **kwargs: typing.Any
                ) -> ListEnvironmentsResponseHttpRequest: ...
                def update(
                    self,
                    *,
                    accountId: str,
                    containerId: str,
                    environmentId: str,
                    body: Environment = ...,
                    fingerprint: str = ...,
                    **kwargs: typing.Any
                ) -> EnvironmentHttpRequest: ...

            @typing.type_check_only
            class FoldersResource(googleapiclient.discovery.Resource):
                @typing.type_check_only
                class EntitiesResource(googleapiclient.discovery.Resource):
                    def list(
                        self,
                        *,
                        accountId: str,
                        containerId: str,
                        folderId: str,
                        **kwargs: typing.Any
                    ) -> FolderEntitiesHttpRequest: ...

                def create(
                    self,
                    *,
                    accountId: str,
                    containerId: str,
                    body: Folder = ...,
                    **kwargs: typing.Any
                ) -> FolderHttpRequest: ...
                def delete(
                    self,
                    *,
                    accountId: str,
                    containerId: str,
                    folderId: str,
                    **kwargs: typing.Any
                ) -> googleapiclient.http.HttpRequest: ...
                def get(
                    self,
                    *,
                    accountId: str,
                    containerId: str,
                    folderId: str,
                    **kwargs: typing.Any
                ) -> FolderHttpRequest: ...
                def list(
                    self, *, accountId: str, containerId: str, **kwargs: typing.Any
                ) -> ListFoldersResponseHttpRequest: ...
                def update(
                    self,
                    *,
                    accountId: str,
                    containerId: str,
                    folderId: str,
                    body: Folder = ...,
                    fingerprint: str = ...,
                    **kwargs: typing.Any
                ) -> FolderHttpRequest: ...
                def entities(self) -> EntitiesResource: ...

            @typing.type_check_only
            class Move_foldersResource(googleapiclient.discovery.Resource):
                def update(
                    self,
                    *,
                    accountId: str,
                    containerId: str,
                    folderId: str,
                    body: Folder = ...,
                    tagId: str | _list[str] = ...,
                    triggerId: str | _list[str] = ...,
                    variableId: str | _list[str] = ...,
                    **kwargs: typing.Any
                ) -> googleapiclient.http.HttpRequest: ...

            @typing.type_check_only
            class Reauthorize_environmentsResource(googleapiclient.discovery.Resource):
                def update(
                    self,
                    *,
                    accountId: str,
                    containerId: str,
                    environmentId: str,
                    body: Environment = ...,
                    **kwargs: typing.Any
                ) -> EnvironmentHttpRequest: ...

            @typing.type_check_only
            class TagsResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    accountId: str,
                    containerId: str,
                    body: Tag = ...,
                    **kwargs: typing.Any
                ) -> TagHttpRequest: ...
                def delete(
                    self,
                    *,
                    accountId: str,
                    containerId: str,
                    tagId: str,
                    **kwargs: typing.Any
                ) -> googleapiclient.http.HttpRequest: ...
                def get(
                    self,
                    *,
                    accountId: str,
                    containerId: str,
                    tagId: str,
                    **kwargs: typing.Any
                ) -> TagHttpRequest: ...
                def list(
                    self, *, accountId: str, containerId: str, **kwargs: typing.Any
                ) -> ListTagsResponseHttpRequest: ...
                def update(
                    self,
                    *,
                    accountId: str,
                    containerId: str,
                    tagId: str,
                    body: Tag = ...,
                    fingerprint: str = ...,
                    **kwargs: typing.Any
                ) -> TagHttpRequest: ...

            @typing.type_check_only
            class TriggersResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    accountId: str,
                    containerId: str,
                    body: Trigger = ...,
                    **kwargs: typing.Any
                ) -> TriggerHttpRequest: ...
                def delete(
                    self,
                    *,
                    accountId: str,
                    containerId: str,
                    triggerId: str,
                    **kwargs: typing.Any
                ) -> googleapiclient.http.HttpRequest: ...
                def get(
                    self,
                    *,
                    accountId: str,
                    containerId: str,
                    triggerId: str,
                    **kwargs: typing.Any
                ) -> TriggerHttpRequest: ...
                def list(
                    self, *, accountId: str, containerId: str, **kwargs: typing.Any
                ) -> ListTriggersResponseHttpRequest: ...
                def update(
                    self,
                    *,
                    accountId: str,
                    containerId: str,
                    triggerId: str,
                    body: Trigger = ...,
                    fingerprint: str = ...,
                    **kwargs: typing.Any
                ) -> TriggerHttpRequest: ...

            @typing.type_check_only
            class VariablesResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    accountId: str,
                    containerId: str,
                    body: Variable = ...,
                    **kwargs: typing.Any
                ) -> VariableHttpRequest: ...
                def delete(
                    self,
                    *,
                    accountId: str,
                    containerId: str,
                    variableId: str,
                    **kwargs: typing.Any
                ) -> googleapiclient.http.HttpRequest: ...
                def get(
                    self,
                    *,
                    accountId: str,
                    containerId: str,
                    variableId: str,
                    **kwargs: typing.Any
                ) -> VariableHttpRequest: ...
                def list(
                    self, *, accountId: str, containerId: str, **kwargs: typing.Any
                ) -> ListVariablesResponseHttpRequest: ...
                def update(
                    self,
                    *,
                    accountId: str,
                    containerId: str,
                    variableId: str,
                    body: Variable = ...,
                    fingerprint: str = ...,
                    **kwargs: typing.Any
                ) -> VariableHttpRequest: ...

            @typing.type_check_only
            class VersionsResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    accountId: str,
                    containerId: str,
                    body: CreateContainerVersionRequestVersionOptions = ...,
                    **kwargs: typing.Any
                ) -> CreateContainerVersionResponseHttpRequest: ...
                def delete(
                    self,
                    *,
                    accountId: str,
                    containerId: str,
                    containerVersionId: str,
                    **kwargs: typing.Any
                ) -> googleapiclient.http.HttpRequest: ...
                def get(
                    self,
                    *,
                    accountId: str,
                    containerId: str,
                    containerVersionId: str,
                    **kwargs: typing.Any
                ) -> ContainerVersionHttpRequest: ...
                def list(
                    self,
                    *,
                    accountId: str,
                    containerId: str,
                    headers: bool = ...,
                    includeDeleted: bool = ...,
                    **kwargs: typing.Any
                ) -> ListContainerVersionsResponseHttpRequest: ...
                def publish(
                    self,
                    *,
                    accountId: str,
                    containerId: str,
                    containerVersionId: str,
                    fingerprint: str = ...,
                    **kwargs: typing.Any
                ) -> PublishContainerVersionResponseHttpRequest: ...
                def restore(
                    self,
                    *,
                    accountId: str,
                    containerId: str,
                    containerVersionId: str,
                    **kwargs: typing.Any
                ) -> ContainerVersionHttpRequest: ...
                def undelete(
                    self,
                    *,
                    accountId: str,
                    containerId: str,
                    containerVersionId: str,
                    **kwargs: typing.Any
                ) -> ContainerVersionHttpRequest: ...
                def update(
                    self,
                    *,
                    accountId: str,
                    containerId: str,
                    containerVersionId: str,
                    body: ContainerVersion = ...,
                    fingerprint: str = ...,
                    **kwargs: typing.Any
                ) -> ContainerVersionHttpRequest: ...

            def create(
                self, *, accountId: str, body: Container = ..., **kwargs: typing.Any
            ) -> ContainerHttpRequest: ...
            def delete(
                self, *, accountId: str, containerId: str, **kwargs: typing.Any
            ) -> googleapiclient.http.HttpRequest: ...
            def get(
                self, *, accountId: str, containerId: str, **kwargs: typing.Any
            ) -> ContainerHttpRequest: ...
            def list(
                self, *, accountId: str, **kwargs: typing.Any
            ) -> ListContainersResponseHttpRequest: ...
            def update(
                self,
                *,
                accountId: str,
                containerId: str,
                body: Container = ...,
                fingerprint: str = ...,
                **kwargs: typing.Any
            ) -> ContainerHttpRequest: ...
            def environments(self) -> EnvironmentsResource: ...
            def folders(self) -> FoldersResource: ...
            def move_folders(self) -> Move_foldersResource: ...
            def reauthorize_environments(self) -> Reauthorize_environmentsResource: ...
            def tags(self) -> TagsResource: ...
            def triggers(self) -> TriggersResource: ...
            def variables(self) -> VariablesResource: ...
            def versions(self) -> VersionsResource: ...

        @typing.type_check_only
        class PermissionsResource(googleapiclient.discovery.Resource):
            def create(
                self, *, accountId: str, body: UserAccess = ..., **kwargs: typing.Any
            ) -> UserAccessHttpRequest: ...
            def delete(
                self, *, accountId: str, permissionId: str, **kwargs: typing.Any
            ) -> googleapiclient.http.HttpRequest: ...
            def get(
                self, *, accountId: str, permissionId: str, **kwargs: typing.Any
            ) -> UserAccessHttpRequest: ...
            def list(
                self, *, accountId: str, **kwargs: typing.Any
            ) -> ListAccountUsersResponseHttpRequest: ...
            def update(
                self,
                *,
                accountId: str,
                permissionId: str,
                body: UserAccess = ...,
                **kwargs: typing.Any
            ) -> UserAccessHttpRequest: ...

        def get(
            self, *, accountId: str, **kwargs: typing.Any
        ) -> AccountHttpRequest: ...
        def list(self, **kwargs: typing.Any) -> ListAccountsResponseHttpRequest: ...
        def update(
            self,
            *,
            accountId: str,
            body: Account = ...,
            fingerprint: str = ...,
            **kwargs: typing.Any
        ) -> AccountHttpRequest: ...
        def containers(self) -> ContainersResource: ...
        def permissions(self) -> PermissionsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def accounts(self) -> AccountsResource: ...

@typing.type_check_only
class AccountHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Account: ...

@typing.type_check_only
class ContainerHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Container: ...

@typing.type_check_only
class ContainerVersionHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ContainerVersion: ...

@typing.type_check_only
class CreateContainerVersionResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> CreateContainerVersionResponse: ...

@typing.type_check_only
class EnvironmentHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Environment: ...

@typing.type_check_only
class FolderHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Folder: ...

@typing.type_check_only
class FolderEntitiesHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> FolderEntities: ...

@typing.type_check_only
class ListAccountUsersResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListAccountUsersResponse: ...

@typing.type_check_only
class ListAccountsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListAccountsResponse: ...

@typing.type_check_only
class ListContainerVersionsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListContainerVersionsResponse: ...

@typing.type_check_only
class ListContainersResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListContainersResponse: ...

@typing.type_check_only
class ListEnvironmentsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListEnvironmentsResponse: ...

@typing.type_check_only
class ListFoldersResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListFoldersResponse: ...

@typing.type_check_only
class ListTagsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListTagsResponse: ...

@typing.type_check_only
class ListTriggersResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListTriggersResponse: ...

@typing.type_check_only
class ListVariablesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListVariablesResponse: ...

@typing.type_check_only
class PublishContainerVersionResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> PublishContainerVersionResponse: ...

@typing.type_check_only
class TagHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Tag: ...

@typing.type_check_only
class TriggerHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Trigger: ...

@typing.type_check_only
class UserAccessHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> UserAccess: ...

@typing.type_check_only
class VariableHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Variable: ...



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['apiclient-stubs', 'googleapiclient-stubs']

package_data = \
{'': ['*'],
 'googleapiclient-stubs': ['_apis/*',
                           '_apis/abusiveexperiencereport/*',
                           '_apis/abusiveexperiencereport/v1/*',
                           '_apis/acceleratedmobilepageurl/*',
                           '_apis/acceleratedmobilepageurl/v1/*',
                           '_apis/accessapproval/*',
                           '_apis/accessapproval/v1/*',
                           '_apis/accesscontextmanager/*',
                           '_apis/accesscontextmanager/v1/*',
                           '_apis/accesscontextmanager/v1beta/*',
                           '_apis/adexchangebuyer/*',
                           '_apis/adexchangebuyer/v1_2/*',
                           '_apis/adexchangebuyer/v1_3/*',
                           '_apis/adexchangebuyer/v1_4/*',
                           '_apis/adexchangebuyer2/*',
                           '_apis/adexchangebuyer2/v2beta1/*',
                           '_apis/adexperiencereport/*',
                           '_apis/adexperiencereport/v1/*',
                           '_apis/admin/*',
                           '_apis/admin/datatransfer_v1/*',
                           '_apis/admin/directory_v1/*',
                           '_apis/admin/reports_v1/*',
                           '_apis/admob/*',
                           '_apis/admob/v1/*',
                           '_apis/admob/v1beta/*',
                           '_apis/adsense/*',
                           '_apis/adsense/v2/*',
                           '_apis/adsensehost/*',
                           '_apis/adsensehost/v4_1/*',
                           '_apis/alertcenter/*',
                           '_apis/alertcenter/v1beta1/*',
                           '_apis/analytics/*',
                           '_apis/analytics/v3/*',
                           '_apis/analyticsadmin/*',
                           '_apis/analyticsadmin/v1alpha/*',
                           '_apis/analyticsdata/*',
                           '_apis/analyticsdata/v1alpha/*',
                           '_apis/analyticsdata/v1beta/*',
                           '_apis/analyticshub/*',
                           '_apis/analyticshub/v1/*',
                           '_apis/analyticshub/v1beta1/*',
                           '_apis/analyticsreporting/*',
                           '_apis/analyticsreporting/v4/*',
                           '_apis/androiddeviceprovisioning/*',
                           '_apis/androiddeviceprovisioning/v1/*',
                           '_apis/androidenterprise/*',
                           '_apis/androidenterprise/v1/*',
                           '_apis/androidmanagement/*',
                           '_apis/androidmanagement/v1/*',
                           '_apis/androidpublisher/*',
                           '_apis/androidpublisher/v3/*',
                           '_apis/apigateway/*',
                           '_apis/apigateway/v1/*',
                           '_apis/apigateway/v1beta/*',
                           '_apis/apigee/*',
                           '_apis/apigee/v1/*',
                           '_apis/apigeeregistry/*',
                           '_apis/apigeeregistry/v1/*',
                           '_apis/apikeys/*',
                           '_apis/apikeys/v2/*',
                           '_apis/appengine/*',
                           '_apis/appengine/v1/*',
                           '_apis/appengine/v1alpha/*',
                           '_apis/appengine/v1beta/*',
                           '_apis/appengine/v1beta4/*',
                           '_apis/appengine/v1beta5/*',
                           '_apis/area120tables/*',
                           '_apis/area120tables/v1alpha1/*',
                           '_apis/artifactregistry/*',
                           '_apis/artifactregistry/v1/*',
                           '_apis/artifactregistry/v1beta1/*',
                           '_apis/artifactregistry/v1beta2/*',
                           '_apis/assuredworkloads/*',
                           '_apis/assuredworkloads/v1/*',
                           '_apis/assuredworkloads/v1beta1/*',
                           '_apis/authorizedbuyersmarketplace/*',
                           '_apis/authorizedbuyersmarketplace/v1/*',
                           '_apis/baremetalsolution/*',
                           '_apis/baremetalsolution/v1/*',
                           '_apis/baremetalsolution/v1alpha1/*',
                           '_apis/baremetalsolution/v2/*',
                           '_apis/beyondcorp/*',
                           '_apis/beyondcorp/v1/*',
                           '_apis/beyondcorp/v1alpha/*',
                           '_apis/bigquery/*',
                           '_apis/bigquery/v2/*',
                           '_apis/bigqueryconnection/*',
                           '_apis/bigqueryconnection/v1beta1/*',
                           '_apis/bigquerydatatransfer/*',
                           '_apis/bigquerydatatransfer/v1/*',
                           '_apis/bigqueryreservation/*',
                           '_apis/bigqueryreservation/v1/*',
                           '_apis/bigqueryreservation/v1alpha2/*',
                           '_apis/bigqueryreservation/v1beta1/*',
                           '_apis/bigtableadmin/*',
                           '_apis/bigtableadmin/v1/*',
                           '_apis/bigtableadmin/v2/*',
                           '_apis/billingbudgets/*',
                           '_apis/billingbudgets/v1/*',
                           '_apis/billingbudgets/v1beta1/*',
                           '_apis/binaryauthorization/*',
                           '_apis/binaryauthorization/v1/*',
                           '_apis/binaryauthorization/v1beta1/*',
                           '_apis/blogger/*',
                           '_apis/blogger/v2/*',
                           '_apis/blogger/v3/*',
                           '_apis/books/*',
                           '_apis/books/v1/*',
                           '_apis/businessprofileperformance/*',
                           '_apis/businessprofileperformance/v1/*',
                           '_apis/calendar/*',
                           '_apis/calendar/v3/*',
                           '_apis/certificatemanager/*',
                           '_apis/certificatemanager/v1/*',
                           '_apis/chat/*',
                           '_apis/chat/v1/*',
                           '_apis/chromemanagement/*',
                           '_apis/chromemanagement/v1/*',
                           '_apis/chromepolicy/*',
                           '_apis/chromepolicy/v1/*',
                           '_apis/chromeuxreport/*',
                           '_apis/chromeuxreport/v1/*',
                           '_apis/civicinfo/*',
                           '_apis/civicinfo/v2/*',
                           '_apis/classroom/*',
                           '_apis/classroom/v1/*',
                           '_apis/cloudasset/*',
                           '_apis/cloudasset/v1/*',
                           '_apis/cloudasset/v1beta1/*',
                           '_apis/cloudasset/v1p1beta1/*',
                           '_apis/cloudasset/v1p4beta1/*',
                           '_apis/cloudasset/v1p5beta1/*',
                           '_apis/cloudasset/v1p7beta1/*',
                           '_apis/cloudbilling/*',
                           '_apis/cloudbilling/v1/*',
                           '_apis/cloudbilling/v1beta/*',
                           '_apis/cloudbuild/*',
                           '_apis/cloudbuild/v1/*',
                           '_apis/cloudbuild/v1alpha1/*',
                           '_apis/cloudbuild/v1alpha2/*',
                           '_apis/cloudbuild/v1beta1/*',
                           '_apis/cloudchannel/*',
                           '_apis/cloudchannel/v1/*',
                           '_apis/cloudcommerceprocurement/*',
                           '_apis/cloudcommerceprocurement/v1/*',
                           '_apis/clouddebugger/*',
                           '_apis/clouddebugger/v2/*',
                           '_apis/clouddeploy/*',
                           '_apis/clouddeploy/v1/*',
                           '_apis/clouderrorreporting/*',
                           '_apis/clouderrorreporting/v1beta1/*',
                           '_apis/cloudfunctions/*',
                           '_apis/cloudfunctions/v1/*',
                           '_apis/cloudfunctions/v2/*',
                           '_apis/cloudfunctions/v2alpha/*',
                           '_apis/cloudfunctions/v2beta/*',
                           '_apis/cloudidentity/*',
                           '_apis/cloudidentity/v1/*',
                           '_apis/cloudidentity/v1beta1/*',
                           '_apis/cloudiot/*',
                           '_apis/cloudiot/v1/*',
                           '_apis/cloudkms/*',
                           '_apis/cloudkms/v1/*',
                           '_apis/cloudprofiler/*',
                           '_apis/cloudprofiler/v2/*',
                           '_apis/cloudresourcemanager/*',
                           '_apis/cloudresourcemanager/v1/*',
                           '_apis/cloudresourcemanager/v1beta1/*',
                           '_apis/cloudresourcemanager/v2/*',
                           '_apis/cloudresourcemanager/v2beta1/*',
                           '_apis/cloudresourcemanager/v3/*',
                           '_apis/cloudscheduler/*',
                           '_apis/cloudscheduler/v1/*',
                           '_apis/cloudscheduler/v1beta1/*',
                           '_apis/cloudsearch/*',
                           '_apis/cloudsearch/v1/*',
                           '_apis/cloudshell/*',
                           '_apis/cloudshell/v1/*',
                           '_apis/cloudshell/v1alpha1/*',
                           '_apis/cloudsupport/*',
                           '_apis/cloudsupport/v2beta/*',
                           '_apis/cloudtasks/*',
                           '_apis/cloudtasks/v2/*',
                           '_apis/cloudtasks/v2beta2/*',
                           '_apis/cloudtasks/v2beta3/*',
                           '_apis/cloudtrace/*',
                           '_apis/cloudtrace/v1/*',
                           '_apis/cloudtrace/v2/*',
                           '_apis/cloudtrace/v2beta1/*',
                           '_apis/composer/*',
                           '_apis/composer/v1/*',
                           '_apis/composer/v1beta1/*',
                           '_apis/compute/*',
                           '_apis/compute/alpha/*',
                           '_apis/compute/beta/*',
                           '_apis/compute/v1/*',
                           '_apis/connectors/*',
                           '_apis/connectors/v1/*',
                           '_apis/connectors/v2/*',
                           '_apis/contactcenterinsights/*',
                           '_apis/contactcenterinsights/v1/*',
                           '_apis/container/*',
                           '_apis/container/v1/*',
                           '_apis/container/v1beta1/*',
                           '_apis/containeranalysis/*',
                           '_apis/containeranalysis/v1/*',
                           '_apis/containeranalysis/v1alpha1/*',
                           '_apis/containeranalysis/v1beta1/*',
                           '_apis/content/*',
                           '_apis/content/v2/*',
                           '_apis/content/v2_1/*',
                           '_apis/contentwarehouse/*',
                           '_apis/contentwarehouse/v1/*',
                           '_apis/customsearch/*',
                           '_apis/customsearch/v1/*',
                           '_apis/datacatalog/*',
                           '_apis/datacatalog/v1/*',
                           '_apis/datacatalog/v1beta1/*',
                           '_apis/dataflow/*',
                           '_apis/dataflow/v1b3/*',
                           '_apis/datafusion/*',
                           '_apis/datafusion/v1/*',
                           '_apis/datafusion/v1beta1/*',
                           '_apis/datalabeling/*',
                           '_apis/datalabeling/v1beta1/*',
                           '_apis/datamigration/*',
                           '_apis/datamigration/v1/*',
                           '_apis/datamigration/v1beta1/*',
                           '_apis/datapipelines/*',
                           '_apis/datapipelines/v1/*',
                           '_apis/dataplex/*',
                           '_apis/dataplex/v1/*',
                           '_apis/dataproc/*',
                           '_apis/dataproc/v1/*',
                           '_apis/dataproc/v1beta2/*',
                           '_apis/datastore/*',
                           '_apis/datastore/v1/*',
                           '_apis/datastore/v1beta1/*',
                           '_apis/datastore/v1beta3/*',
                           '_apis/datastream/*',
                           '_apis/datastream/v1/*',
                           '_apis/datastream/v1alpha1/*',
                           '_apis/deploymentmanager/*',
                           '_apis/deploymentmanager/alpha/*',
                           '_apis/deploymentmanager/v2/*',
                           '_apis/deploymentmanager/v2beta/*',
                           '_apis/dfareporting/*',
                           '_apis/dfareporting/v3_3/*',
                           '_apis/dfareporting/v3_4/*',
                           '_apis/dfareporting/v3_5/*',
                           '_apis/dfareporting/v4/*',
                           '_apis/dialogflow/*',
                           '_apis/dialogflow/v2/*',
                           '_apis/dialogflow/v2beta1/*',
                           '_apis/dialogflow/v3/*',
                           '_apis/dialogflow/v3beta1/*',
                           '_apis/digitalassetlinks/*',
                           '_apis/digitalassetlinks/v1/*',
                           '_apis/discovery/*',
                           '_apis/discovery/v1/*',
                           '_apis/displayvideo/*',
                           '_apis/displayvideo/v1/*',
                           '_apis/displayvideo/v2/*',
                           '_apis/dlp/*',
                           '_apis/dlp/v2/*',
                           '_apis/dns/*',
                           '_apis/dns/v1/*',
                           '_apis/dns/v1beta2/*',
                           '_apis/dns/v2/*',
                           '_apis/docs/*',
                           '_apis/docs/v1/*',
                           '_apis/documentai/*',
                           '_apis/documentai/v1/*',
                           '_apis/documentai/v1beta2/*',
                           '_apis/documentai/v1beta3/*',
                           '_apis/domains/*',
                           '_apis/domains/v1/*',
                           '_apis/domains/v1alpha2/*',
                           '_apis/domains/v1beta1/*',
                           '_apis/domainsrdap/*',
                           '_apis/domainsrdap/v1/*',
                           '_apis/doubleclickbidmanager/*',
                           '_apis/doubleclickbidmanager/v1/*',
                           '_apis/doubleclickbidmanager/v1_1/*',
                           '_apis/doubleclickbidmanager/v2/*',
                           '_apis/doubleclicksearch/*',
                           '_apis/doubleclicksearch/v2/*',
                           '_apis/drive/*',
                           '_apis/drive/v2/*',
                           '_apis/drive/v3/*',
                           '_apis/driveactivity/*',
                           '_apis/driveactivity/v2/*',
                           '_apis/drivelabels/*',
                           '_apis/drivelabels/v2/*',
                           '_apis/drivelabels/v2beta/*',
                           '_apis/essentialcontacts/*',
                           '_apis/essentialcontacts/v1/*',
                           '_apis/eventarc/*',
                           '_apis/eventarc/v1/*',
                           '_apis/eventarc/v1beta1/*',
                           '_apis/factchecktools/*',
                           '_apis/factchecktools/v1alpha1/*',
                           '_apis/fcm/*',
                           '_apis/fcm/v1/*',
                           '_apis/fcmdata/*',
                           '_apis/fcmdata/v1beta1/*',
                           '_apis/file/*',
                           '_apis/file/v1/*',
                           '_apis/file/v1beta1/*',
                           '_apis/firebase/*',
                           '_apis/firebase/v1beta1/*',
                           '_apis/firebaseappcheck/*',
                           '_apis/firebaseappcheck/v1/*',
                           '_apis/firebaseappcheck/v1beta/*',
                           '_apis/firebasedatabase/*',
                           '_apis/firebasedatabase/v1beta/*',
                           '_apis/firebasedynamiclinks/*',
                           '_apis/firebasedynamiclinks/v1/*',
                           '_apis/firebasehosting/*',
                           '_apis/firebasehosting/v1/*',
                           '_apis/firebasehosting/v1beta1/*',
                           '_apis/firebaseml/*',
                           '_apis/firebaseml/v1/*',
                           '_apis/firebaseml/v1beta2/*',
                           '_apis/firebaserules/*',
                           '_apis/firebaserules/v1/*',
                           '_apis/firebasestorage/*',
                           '_apis/firebasestorage/v1beta/*',
                           '_apis/firestore/*',
                           '_apis/firestore/v1/*',
                           '_apis/firestore/v1beta1/*',
                           '_apis/firestore/v1beta2/*',
                           '_apis/fitness/*',
                           '_apis/fitness/v1/*',
                           '_apis/forms/*',
                           '_apis/forms/v1/*',
                           '_apis/games/*',
                           '_apis/games/v1/*',
                           '_apis/gamesConfiguration/*',
                           '_apis/gamesConfiguration/v1configuration/*',
                           '_apis/gamesManagement/*',
                           '_apis/gamesManagement/v1management/*',
                           '_apis/gameservices/*',
                           '_apis/gameservices/v1/*',
                           '_apis/gameservices/v1beta/*',
                           '_apis/genomics/*',
                           '_apis/genomics/v1/*',
                           '_apis/genomics/v1alpha2/*',
                           '_apis/genomics/v2alpha1/*',
                           '_apis/gkebackup/*',
                           '_apis/gkebackup/v1/*',
                           '_apis/gkehub/*',
                           '_apis/gkehub/v1/*',
                           '_apis/gkehub/v1alpha/*',
                           '_apis/gkehub/v1alpha2/*',
                           '_apis/gkehub/v1beta/*',
                           '_apis/gkehub/v1beta1/*',
                           '_apis/gkehub/v2alpha/*',
                           '_apis/gmail/*',
                           '_apis/gmail/v1/*',
                           '_apis/gmailpostmastertools/*',
                           '_apis/gmailpostmastertools/v1/*',
                           '_apis/gmailpostmastertools/v1beta1/*',
                           '_apis/groupsmigration/*',
                           '_apis/groupsmigration/v1/*',
                           '_apis/groupssettings/*',
                           '_apis/groupssettings/v1/*',
                           '_apis/healthcare/*',
                           '_apis/healthcare/v1/*',
                           '_apis/healthcare/v1beta1/*',
                           '_apis/homegraph/*',
                           '_apis/homegraph/v1/*',
                           '_apis/iam/*',
                           '_apis/iam/v1/*',
                           '_apis/iam/v2beta/*',
                           '_apis/iamcredentials/*',
                           '_apis/iamcredentials/v1/*',
                           '_apis/iap/*',
                           '_apis/iap/v1/*',
                           '_apis/iap/v1beta1/*',
                           '_apis/ideahub/*',
                           '_apis/ideahub/v1alpha/*',
                           '_apis/ideahub/v1beta/*',
                           '_apis/identitytoolkit/*',
                           '_apis/identitytoolkit/v1/*',
                           '_apis/identitytoolkit/v2/*',
                           '_apis/identitytoolkit/v3/*',
                           '_apis/ids/*',
                           '_apis/ids/v1/*',
                           '_apis/indexing/*',
                           '_apis/indexing/v3/*',
                           '_apis/integrations/*',
                           '_apis/integrations/v1alpha/*',
                           '_apis/jobs/*',
                           '_apis/jobs/v2/*',
                           '_apis/jobs/v3/*',
                           '_apis/jobs/v3p1beta1/*',
                           '_apis/jobs/v4/*',
                           '_apis/keep/*',
                           '_apis/keep/v1/*',
                           '_apis/kgsearch/*',
                           '_apis/kgsearch/v1/*',
                           '_apis/language/*',
                           '_apis/language/v1/*',
                           '_apis/language/v1beta1/*',
                           '_apis/language/v1beta2/*',
                           '_apis/libraryagent/*',
                           '_apis/libraryagent/v1/*',
                           '_apis/licensing/*',
                           '_apis/licensing/v1/*',
                           '_apis/lifesciences/*',
                           '_apis/lifesciences/v2beta/*',
                           '_apis/localservices/*',
                           '_apis/localservices/v1/*',
                           '_apis/logging/*',
                           '_apis/logging/v2/*',
                           '_apis/managedidentities/*',
                           '_apis/managedidentities/v1/*',
                           '_apis/managedidentities/v1alpha1/*',
                           '_apis/managedidentities/v1beta1/*',
                           '_apis/manufacturers/*',
                           '_apis/manufacturers/v1/*',
                           '_apis/memcache/*',
                           '_apis/memcache/v1/*',
                           '_apis/memcache/v1beta2/*',
                           '_apis/metastore/*',
                           '_apis/metastore/v1alpha/*',
                           '_apis/metastore/v1beta/*',
                           '_apis/ml/*',
                           '_apis/ml/v1/*',
                           '_apis/monitoring/*',
                           '_apis/monitoring/v1/*',
                           '_apis/monitoring/v3/*',
                           '_apis/mybusinessaccountmanagement/*',
                           '_apis/mybusinessaccountmanagement/v1/*',
                           '_apis/mybusinessbusinesscalls/*',
                           '_apis/mybusinessbusinesscalls/v1/*',
                           '_apis/mybusinessbusinessinformation/*',
                           '_apis/mybusinessbusinessinformation/v1/*',
                           '_apis/mybusinesslodging/*',
                           '_apis/mybusinesslodging/v1/*',
                           '_apis/mybusinessnotifications/*',
                           '_apis/mybusinessnotifications/v1/*',
                           '_apis/mybusinessplaceactions/*',
                           '_apis/mybusinessplaceactions/v1/*',
                           '_apis/mybusinessqanda/*',
                           '_apis/mybusinessqanda/v1/*',
                           '_apis/mybusinessverifications/*',
                           '_apis/mybusinessverifications/v1/*',
                           '_apis/networkconnectivity/*',
                           '_apis/networkconnectivity/v1/*',
                           '_apis/networkconnectivity/v1alpha1/*',
                           '_apis/networkmanagement/*',
                           '_apis/networkmanagement/v1/*',
                           '_apis/networkmanagement/v1beta1/*',
                           '_apis/networksecurity/*',
                           '_apis/networksecurity/v1/*',
                           '_apis/networksecurity/v1beta1/*',
                           '_apis/networkservices/*',
                           '_apis/networkservices/v1/*',
                           '_apis/networkservices/v1beta1/*',
                           '_apis/notebooks/*',
                           '_apis/notebooks/v1/*',
                           '_apis/oauth2/*',
                           '_apis/oauth2/v2/*',
                           '_apis/ondemandscanning/*',
                           '_apis/ondemandscanning/v1/*',
                           '_apis/ondemandscanning/v1beta1/*',
                           '_apis/orgpolicy/*',
                           '_apis/orgpolicy/v2/*',
                           '_apis/osconfig/*',
                           '_apis/osconfig/v1/*',
                           '_apis/osconfig/v1alpha/*',
                           '_apis/osconfig/v1beta/*',
                           '_apis/oslogin/*',
                           '_apis/oslogin/v1/*',
                           '_apis/oslogin/v1alpha/*',
                           '_apis/oslogin/v1beta/*',
                           '_apis/pagespeedonline/*',
                           '_apis/pagespeedonline/v5/*',
                           '_apis/paymentsresellersubscription/*',
                           '_apis/paymentsresellersubscription/v1/*',
                           '_apis/people/*',
                           '_apis/people/v1/*',
                           '_apis/playablelocations/*',
                           '_apis/playablelocations/v3/*',
                           '_apis/playcustomapp/*',
                           '_apis/playcustomapp/v1/*',
                           '_apis/playdeveloperreporting/*',
                           '_apis/playdeveloperreporting/v1alpha1/*',
                           '_apis/playdeveloperreporting/v1beta1/*',
                           '_apis/playintegrity/*',
                           '_apis/playintegrity/v1/*',
                           '_apis/policyanalyzer/*',
                           '_apis/policyanalyzer/v1/*',
                           '_apis/policyanalyzer/v1beta1/*',
                           '_apis/policysimulator/*',
                           '_apis/policysimulator/v1/*',
                           '_apis/policysimulator/v1alpha/*',
                           '_apis/policysimulator/v1beta1/*',
                           '_apis/policytroubleshooter/*',
                           '_apis/policytroubleshooter/v1/*',
                           '_apis/policytroubleshooter/v1beta/*',
                           '_apis/poly/*',
                           '_apis/poly/v1/*',
                           '_apis/privateca/*',
                           '_apis/privateca/v1/*',
                           '_apis/privateca/v1beta1/*',
                           '_apis/prod_tt_sasportal/*',
                           '_apis/prod_tt_sasportal/v1alpha1/*',
                           '_apis/pubsub/*',
                           '_apis/pubsub/v1/*',
                           '_apis/pubsub/v1beta1a/*',
                           '_apis/pubsub/v1beta2/*',
                           '_apis/pubsublite/*',
                           '_apis/pubsublite/v1/*',
                           '_apis/realtimebidding/*',
                           '_apis/realtimebidding/v1/*',
                           '_apis/realtimebidding/v1alpha/*',
                           '_apis/recaptchaenterprise/*',
                           '_apis/recaptchaenterprise/v1/*',
                           '_apis/recommendationengine/*',
                           '_apis/recommendationengine/v1beta1/*',
                           '_apis/recommender/*',
                           '_apis/recommender/v1/*',
                           '_apis/recommender/v1beta1/*',
                           '_apis/redis/*',
                           '_apis/redis/v1/*',
                           '_apis/redis/v1beta1/*',
                           '_apis/remotebuildexecution/*',
                           '_apis/remotebuildexecution/v1/*',
                           '_apis/remotebuildexecution/v1alpha/*',
                           '_apis/remotebuildexecution/v2/*',
                           '_apis/reseller/*',
                           '_apis/reseller/v1/*',
                           '_apis/resourcesettings/*',
                           '_apis/resourcesettings/v1/*',
                           '_apis/retail/*',
                           '_apis/retail/v2/*',
                           '_apis/retail/v2alpha/*',
                           '_apis/retail/v2beta/*',
                           '_apis/run/*',
                           '_apis/run/v1/*',
                           '_apis/run/v1alpha1/*',
                           '_apis/run/v1beta1/*',
                           '_apis/run/v2/*',
                           '_apis/runtimeconfig/*',
                           '_apis/runtimeconfig/v1/*',
                           '_apis/runtimeconfig/v1beta1/*',
                           '_apis/safebrowsing/*',
                           '_apis/safebrowsing/v4/*',
                           '_apis/sasportal/*',
                           '_apis/sasportal/v1alpha1/*',
                           '_apis/script/*',
                           '_apis/script/v1/*',
                           '_apis/searchconsole/*',
                           '_apis/searchconsole/v1/*',
                           '_apis/secretmanager/*',
                           '_apis/secretmanager/v1/*',
                           '_apis/secretmanager/v1beta1/*',
                           '_apis/securitycenter/*',
                           '_apis/securitycenter/v1/*',
                           '_apis/securitycenter/v1beta1/*',
                           '_apis/securitycenter/v1beta2/*',
                           '_apis/serviceconsumermanagement/*',
                           '_apis/serviceconsumermanagement/v1/*',
                           '_apis/serviceconsumermanagement/v1beta1/*',
                           '_apis/servicecontrol/*',
                           '_apis/servicecontrol/v1/*',
                           '_apis/servicecontrol/v2/*',
                           '_apis/servicedirectory/*',
                           '_apis/servicedirectory/v1/*',
                           '_apis/servicedirectory/v1beta1/*',
                           '_apis/servicemanagement/*',
                           '_apis/servicemanagement/v1/*',
                           '_apis/servicenetworking/*',
                           '_apis/servicenetworking/v1/*',
                           '_apis/servicenetworking/v1beta/*',
                           '_apis/serviceusage/*',
                           '_apis/serviceusage/v1/*',
                           '_apis/serviceusage/v1beta1/*',
                           '_apis/sheets/*',
                           '_apis/sheets/v4/*',
                           '_apis/siteVerification/*',
                           '_apis/siteVerification/v1/*',
                           '_apis/slides/*',
                           '_apis/slides/v1/*',
                           '_apis/smartdevicemanagement/*',
                           '_apis/smartdevicemanagement/v1/*',
                           '_apis/sourcerepo/*',
                           '_apis/sourcerepo/v1/*',
                           '_apis/spanner/*',
                           '_apis/spanner/v1/*',
                           '_apis/speech/*',
                           '_apis/speech/v1/*',
                           '_apis/speech/v1p1beta1/*',
                           '_apis/speech/v2beta1/*',
                           '_apis/sqladmin/*',
                           '_apis/sqladmin/v1/*',
                           '_apis/sqladmin/v1beta4/*',
                           '_apis/storage/*',
                           '_apis/storage/v1/*',
                           '_apis/storagetransfer/*',
                           '_apis/storagetransfer/v1/*',
                           '_apis/streetviewpublish/*',
                           '_apis/streetviewpublish/v1/*',
                           '_apis/sts/*',
                           '_apis/sts/v1/*',
                           '_apis/sts/v1beta/*',
                           '_apis/tagmanager/*',
                           '_apis/tagmanager/v1/*',
                           '_apis/tagmanager/v2/*',
                           '_apis/tasks/*',
                           '_apis/tasks/v1/*',
                           '_apis/testing/*',
                           '_apis/testing/v1/*',
                           '_apis/texttospeech/*',
                           '_apis/texttospeech/v1/*',
                           '_apis/texttospeech/v1beta1/*',
                           '_apis/toolresults/*',
                           '_apis/toolresults/v1beta3/*',
                           '_apis/tpu/*',
                           '_apis/tpu/v1/*',
                           '_apis/tpu/v1alpha1/*',
                           '_apis/tpu/v2alpha1/*',
                           '_apis/trafficdirector/*',
                           '_apis/trafficdirector/v2/*',
                           '_apis/transcoder/*',
                           '_apis/transcoder/v1/*',
                           '_apis/transcoder/v1beta1/*',
                           '_apis/translate/*',
                           '_apis/translate/v2/*',
                           '_apis/translate/v3/*',
                           '_apis/translate/v3beta1/*',
                           '_apis/vault/*',
                           '_apis/vault/v1/*',
                           '_apis/vectortile/*',
                           '_apis/vectortile/v1/*',
                           '_apis/verifiedaccess/*',
                           '_apis/verifiedaccess/v1/*',
                           '_apis/verifiedaccess/v2/*',
                           '_apis/versionhistory/*',
                           '_apis/versionhistory/v1/*',
                           '_apis/videointelligence/*',
                           '_apis/videointelligence/v1/*',
                           '_apis/videointelligence/v1beta2/*',
                           '_apis/videointelligence/v1p1beta1/*',
                           '_apis/videointelligence/v1p2beta1/*',
                           '_apis/videointelligence/v1p3beta1/*',
                           '_apis/vision/*',
                           '_apis/vision/v1/*',
                           '_apis/vision/v1p1beta1/*',
                           '_apis/vision/v1p2beta1/*',
                           '_apis/vmmigration/*',
                           '_apis/vmmigration/v1/*',
                           '_apis/vmmigration/v1alpha1/*',
                           '_apis/webfonts/*',
                           '_apis/webfonts/v1/*',
                           '_apis/webmasters/*',
                           '_apis/webmasters/v3/*',
                           '_apis/webrisk/*',
                           '_apis/webrisk/v1/*',
                           '_apis/websecurityscanner/*',
                           '_apis/websecurityscanner/v1/*',
                           '_apis/websecurityscanner/v1alpha/*',
                           '_apis/websecurityscanner/v1beta/*',
                           '_apis/workflowexecutions/*',
                           '_apis/workflowexecutions/v1/*',
                           '_apis/workflowexecutions/v1beta/*',
                           '_apis/workflows/*',
                           '_apis/workflows/v1/*',
                           '_apis/workflows/v1beta/*',
                           '_apis/youtube/*',
                           '_apis/youtube/v3/*',
                           '_apis/youtubeAnalytics/*',
                           '_apis/youtubeAnalytics/v1/*',
                           '_apis/youtubeAnalytics/v2/*',
                           '_apis/youtubereporting/*',
                           '_apis/youtubereporting/v1/*',
                           'discovery_cache/*']}

install_requires = \
['google-api-python-client>=2.64.0', 'typing-extensions>=3.10.0']

setup_kwargs = {
    'name': 'google-api-python-client-stubs',
    'version': '1.14.1',
    'description': 'Type stubs for google-api-python-client',
    'long_description': '# Type stubs for google-api-python-client\n\n[![PyPI version](https://badge.fury.io/py/google-api-python-client-stubs.svg)](https://badge.fury.io/py/google-api-python-client-stubs)\n\nThis package provides type stubs for the [google-api-python-client](https://github.com/googleapis/google-api-python-client) library. \nIt allows you to type check usage of the library with e.g. [mypy](http://mypy-lang.org/) and will also improve autocomplete in many editors.\n\n**This is in no way affiliated with Google.**\n\nThe stubs were generated automatically based on Google\'s [Discovery Documents](https://developers.google.com/discovery/v1/reference/apis), that are bundled with google-api-python-client as of v2.\n\nIf you find incorrect annotations, please create an issue.\n\n## Installation\n\n```shell script\n$ pip install google-api-python-client-stubs\n```\n\n## Caveats\n\n### Performance\nThe stubs contain a separate overload of `googleapiclient.discovery.build` for each service and version (see `discovery.pyi`). \nThis can lead to slow type inference for this function. Mypy will generally be pretty fast after the first run,\nbut you might experience slow autocomplete. If you\'re experiencing this problem you can bypass type inference with explicit annotations, \ne.g. `sheets_service: SheetsResource = build("sheets", "v4")` instead of `sheets_service = build("sheets", "v4")`.\nSee the next section for some caveats to this approach.\n\n### Explicit annotations\nThe `google-api-python-client-stubs` is quite dynamic. \nAll resources are just instances of a single class with dynamically attached methods\nand the requests and responses are just dictionaries. The way this is annotated is with\nclasses and [TypedDicts](https://docs.python.org/3/library/typing.html#typing.TypedDict)\nthat don\'t exist in the actual library, only in the stub files. This means you *cannot* use any of these types at runtime, it *will* cause your code to crash.\nIf you rely solely on type inference, this is not an issue, but as soon as you want to explicitly\nannotate a variable, argument or return type in your code with one of these types, you must follow these rules:\n1. Either put `from __future__ import annotations` at the top of your file or surround the annotations with quotes. \nThis ensures that Python doesn\'t attempt to evaluate the types at runtime. \nNote that the import is only supported in Python 3.7 and above.\n2. Only import the types inside an `if typing.TYPE_CHECKING` block. This ensures that the imports are only evaluated during\ntype checking. Note that any type not available at runtime is located under the `googleapiclient._apis` package. \nFor example, `SheetsResource` should be imported from `googleapiclient._apis.sheets.v4.resources`.\nIf autocompleting import paths doesn\'t work you can find the correct path by using Mypy\'s [reveal_type](https://mypy.readthedocs.io/en/stable/common_issues.html#reveal-type)\non the thing you want to explicitly annotate. For `TypedDict`s this will also give you useful info about the structure of the dictionary.\n\n### Recursive types\nThe stubs previously didn\'t include recursive type definitions due to a lack of type checker support, but this is now included. Note that if you\'re using Mypy, v0.990 or higher is required for this to work.\n\n### Stubs for non-API-specific parts\nThere are detailed stubs for the API services, but other parts of the library have only been annotated with [stubgen](https://mypy.readthedocs.io/en/stable/stubgen.html),\nso they\'re mostly typed as `Any`. I believe these parts are mostly used internally by the library itself,\nso for most users this should be fine. Contributions to improve these stubs are welcome, though.\n',
    'author': 'Henrik Bruådal',
    'author_email': 'henrik.bruasdal@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/henribru/google-api-python-client-stubs',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class StreetViewPublishResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class PhotoResource(googleapiclient.discovery.Resource):
        def create(
            self, *, body: Photo = ..., **kwargs: typing.Any
        ) -> PhotoHttpRequest: ...
        def delete(self, *, photoId: str, **kwargs: typing.Any) -> EmptyHttpRequest: ...
        def get(
            self,
            *,
            photoId: str,
            languageCode: str = ...,
            view: typing_extensions.Literal["BASIC", "INCLUDE_DOWNLOAD_URL"] = ...,
            **kwargs: typing.Any
        ) -> PhotoHttpRequest: ...
        def startUpload(
            self, *, body: Empty = ..., **kwargs: typing.Any
        ) -> UploadRefHttpRequest: ...
        def update(
            self,
            *,
            id: str,
            body: Photo = ...,
            updateMask: str = ...,
            **kwargs: typing.Any
        ) -> PhotoHttpRequest: ...

    @typing.type_check_only
    class PhotoSequenceResource(googleapiclient.discovery.Resource):
        def create(
            self,
            *,
            body: PhotoSequence = ...,
            inputType: typing_extensions.Literal[
                "INPUT_TYPE_UNSPECIFIED", "VIDEO", "XDM"
            ] = ...,
            **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def delete(
            self, *, sequenceId: str, **kwargs: typing.Any
        ) -> EmptyHttpRequest: ...
        def get(
            self,
            *,
            sequenceId: str,
            filter: str = ...,
            view: typing_extensions.Literal["BASIC", "INCLUDE_DOWNLOAD_URL"] = ...,
            **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def startUpload(
            self, *, body: Empty = ..., **kwargs: typing.Any
        ) -> UploadRefHttpRequest: ...

    @typing.type_check_only
    class PhotoSequencesResource(googleapiclient.discovery.Resource):
        def list(
            self,
            *,
            filter: str = ...,
            pageSize: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> ListPhotoSequencesResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: ListPhotoSequencesResponseHttpRequest,
            previous_response: ListPhotoSequencesResponse,
        ) -> ListPhotoSequencesResponseHttpRequest | None: ...

    @typing.type_check_only
    class PhotosResource(googleapiclient.discovery.Resource):
        def batchDelete(
            self, *, body: BatchDeletePhotosRequest = ..., **kwargs: typing.Any
        ) -> BatchDeletePhotosResponseHttpRequest: ...
        def batchGet(
            self,
            *,
            languageCode: str = ...,
            photoIds: str | _list[str] = ...,
            view: typing_extensions.Literal["BASIC", "INCLUDE_DOWNLOAD_URL"] = ...,
            **kwargs: typing.Any
        ) -> BatchGetPhotosResponseHttpRequest: ...
        def batchUpdate(
            self, *, body: BatchUpdatePhotosRequest = ..., **kwargs: typing.Any
        ) -> BatchUpdatePhotosResponseHttpRequest: ...
        def list(
            self,
            *,
            filter: str = ...,
            languageCode: str = ...,
            pageSize: int = ...,
            pageToken: str = ...,
            view: typing_extensions.Literal["BASIC", "INCLUDE_DOWNLOAD_URL"] = ...,
            **kwargs: typing.Any
        ) -> ListPhotosResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: ListPhotosResponseHttpRequest,
            previous_response: ListPhotosResponse,
        ) -> ListPhotosResponseHttpRequest | None: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def photo(self) -> PhotoResource: ...
    def photoSequence(self) -> PhotoSequenceResource: ...
    def photoSequences(self) -> PhotoSequencesResource: ...
    def photos(self) -> PhotosResource: ...

@typing.type_check_only
class BatchDeletePhotosResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> BatchDeletePhotosResponse: ...

@typing.type_check_only
class BatchGetPhotosResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> BatchGetPhotosResponse: ...

@typing.type_check_only
class BatchUpdatePhotosResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> BatchUpdatePhotosResponse: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class ListPhotoSequencesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListPhotoSequencesResponse: ...

@typing.type_check_only
class ListPhotosResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListPhotosResponse: ...

@typing.type_check_only
class OperationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Operation: ...

@typing.type_check_only
class PhotoHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Photo: ...

@typing.type_check_only
class UploadRefHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> UploadRef: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class DataCatalogResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class CatalogResource(googleapiclient.discovery.Resource):
        def search(
            self,
            *,
            body: GoogleCloudDatacatalogV1SearchCatalogRequest = ...,
            **kwargs: typing.Any
        ) -> GoogleCloudDatacatalogV1SearchCatalogResponseHttpRequest: ...
        def search_next(
            self,
            previous_request: GoogleCloudDatacatalogV1SearchCatalogResponseHttpRequest,
            previous_response: GoogleCloudDatacatalogV1SearchCatalogResponse,
        ) -> GoogleCloudDatacatalogV1SearchCatalogResponseHttpRequest | None: ...

    @typing.type_check_only
    class EntriesResource(googleapiclient.discovery.Resource):
        def lookup(
            self,
            *,
            fullyQualifiedName: str = ...,
            linkedResource: str = ...,
            sqlResource: str = ...,
            **kwargs: typing.Any
        ) -> GoogleCloudDatacatalogV1EntryHttpRequest: ...

    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class LocationsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class EntryGroupsResource(googleapiclient.discovery.Resource):
                @typing.type_check_only
                class EntriesResource(googleapiclient.discovery.Resource):
                    @typing.type_check_only
                    class TagsResource(googleapiclient.discovery.Resource):
                        def create(
                            self,
                            *,
                            parent: str,
                            body: GoogleCloudDatacatalogV1Tag = ...,
                            **kwargs: typing.Any
                        ) -> GoogleCloudDatacatalogV1TagHttpRequest: ...
                        def delete(
                            self, *, name: str, **kwargs: typing.Any
                        ) -> EmptyHttpRequest: ...
                        def list(
                            self,
                            *,
                            parent: str,
                            pageSize: int = ...,
                            pageToken: str = ...,
                            **kwargs: typing.Any
                        ) -> GoogleCloudDatacatalogV1ListTagsResponseHttpRequest: ...
                        def list_next(
                            self,
                            previous_request: GoogleCloudDatacatalogV1ListTagsResponseHttpRequest,
                            previous_response: GoogleCloudDatacatalogV1ListTagsResponse,
                        ) -> GoogleCloudDatacatalogV1ListTagsResponseHttpRequest | None: ...
                        def patch(
                            self,
                            *,
                            name: str,
                            body: GoogleCloudDatacatalogV1Tag = ...,
                            updateMask: str = ...,
                            **kwargs: typing.Any
                        ) -> GoogleCloudDatacatalogV1TagHttpRequest: ...

                    def create(
                        self,
                        *,
                        parent: str,
                        body: GoogleCloudDatacatalogV1Entry = ...,
                        entryId: str = ...,
                        **kwargs: typing.Any
                    ) -> GoogleCloudDatacatalogV1EntryHttpRequest: ...
                    def delete(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> EmptyHttpRequest: ...
                    def get(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> GoogleCloudDatacatalogV1EntryHttpRequest: ...
                    def getIamPolicy(
                        self,
                        *,
                        resource: str,
                        body: GetIamPolicyRequest = ...,
                        **kwargs: typing.Any
                    ) -> PolicyHttpRequest: ...
                    def list(
                        self,
                        *,
                        parent: str,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        readMask: str = ...,
                        **kwargs: typing.Any
                    ) -> GoogleCloudDatacatalogV1ListEntriesResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: GoogleCloudDatacatalogV1ListEntriesResponseHttpRequest,
                        previous_response: GoogleCloudDatacatalogV1ListEntriesResponse,
                    ) -> GoogleCloudDatacatalogV1ListEntriesResponseHttpRequest | None: ...
                    def modifyEntryContacts(
                        self,
                        *,
                        name: str,
                        body: GoogleCloudDatacatalogV1ModifyEntryContactsRequest = ...,
                        **kwargs: typing.Any
                    ) -> GoogleCloudDatacatalogV1ContactsHttpRequest: ...
                    def modifyEntryOverview(
                        self,
                        *,
                        name: str,
                        body: GoogleCloudDatacatalogV1ModifyEntryOverviewRequest = ...,
                        **kwargs: typing.Any
                    ) -> GoogleCloudDatacatalogV1EntryOverviewHttpRequest: ...
                    def patch(
                        self,
                        *,
                        name: str,
                        body: GoogleCloudDatacatalogV1Entry = ...,
                        updateMask: str = ...,
                        **kwargs: typing.Any
                    ) -> GoogleCloudDatacatalogV1EntryHttpRequest: ...
                    def star(
                        self,
                        *,
                        name: str,
                        body: GoogleCloudDatacatalogV1StarEntryRequest = ...,
                        **kwargs: typing.Any
                    ) -> GoogleCloudDatacatalogV1StarEntryResponseHttpRequest: ...
                    def testIamPermissions(
                        self,
                        *,
                        resource: str,
                        body: TestIamPermissionsRequest = ...,
                        **kwargs: typing.Any
                    ) -> TestIamPermissionsResponseHttpRequest: ...
                    def unstar(
                        self,
                        *,
                        name: str,
                        body: GoogleCloudDatacatalogV1UnstarEntryRequest = ...,
                        **kwargs: typing.Any
                    ) -> GoogleCloudDatacatalogV1UnstarEntryResponseHttpRequest: ...
                    def tags(self) -> TagsResource: ...

                @typing.type_check_only
                class TagsResource(googleapiclient.discovery.Resource):
                    def create(
                        self,
                        *,
                        parent: str,
                        body: GoogleCloudDatacatalogV1Tag = ...,
                        **kwargs: typing.Any
                    ) -> GoogleCloudDatacatalogV1TagHttpRequest: ...
                    def delete(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> EmptyHttpRequest: ...
                    def list(
                        self,
                        *,
                        parent: str,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        **kwargs: typing.Any
                    ) -> GoogleCloudDatacatalogV1ListTagsResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: GoogleCloudDatacatalogV1ListTagsResponseHttpRequest,
                        previous_response: GoogleCloudDatacatalogV1ListTagsResponse,
                    ) -> GoogleCloudDatacatalogV1ListTagsResponseHttpRequest | None: ...
                    def patch(
                        self,
                        *,
                        name: str,
                        body: GoogleCloudDatacatalogV1Tag = ...,
                        updateMask: str = ...,
                        **kwargs: typing.Any
                    ) -> GoogleCloudDatacatalogV1TagHttpRequest: ...

                def create(
                    self,
                    *,
                    parent: str,
                    body: GoogleCloudDatacatalogV1EntryGroup = ...,
                    entryGroupId: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudDatacatalogV1EntryGroupHttpRequest: ...
                def delete(
                    self, *, name: str, force: bool = ..., **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def get(
                    self, *, name: str, readMask: str = ..., **kwargs: typing.Any
                ) -> GoogleCloudDatacatalogV1EntryGroupHttpRequest: ...
                def getIamPolicy(
                    self,
                    *,
                    resource: str,
                    body: GetIamPolicyRequest = ...,
                    **kwargs: typing.Any
                ) -> PolicyHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudDatacatalogV1ListEntryGroupsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: GoogleCloudDatacatalogV1ListEntryGroupsResponseHttpRequest,
                    previous_response: GoogleCloudDatacatalogV1ListEntryGroupsResponse,
                ) -> GoogleCloudDatacatalogV1ListEntryGroupsResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: GoogleCloudDatacatalogV1EntryGroup = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudDatacatalogV1EntryGroupHttpRequest: ...
                def setIamPolicy(
                    self,
                    *,
                    resource: str,
                    body: SetIamPolicyRequest = ...,
                    **kwargs: typing.Any
                ) -> PolicyHttpRequest: ...
                def testIamPermissions(
                    self,
                    *,
                    resource: str,
                    body: TestIamPermissionsRequest = ...,
                    **kwargs: typing.Any
                ) -> TestIamPermissionsResponseHttpRequest: ...
                def entries(self) -> EntriesResource: ...
                def tags(self) -> TagsResource: ...

            @typing.type_check_only
            class TagTemplatesResource(googleapiclient.discovery.Resource):
                @typing.type_check_only
                class FieldsResource(googleapiclient.discovery.Resource):
                    @typing.type_check_only
                    class EnumValuesResource(googleapiclient.discovery.Resource):
                        def rename(
                            self,
                            *,
                            name: str,
                            body: GoogleCloudDatacatalogV1RenameTagTemplateFieldEnumValueRequest = ...,
                            **kwargs: typing.Any
                        ) -> GoogleCloudDatacatalogV1TagTemplateFieldHttpRequest: ...

                    def create(
                        self,
                        *,
                        parent: str,
                        body: GoogleCloudDatacatalogV1TagTemplateField = ...,
                        tagTemplateFieldId: str = ...,
                        **kwargs: typing.Any
                    ) -> GoogleCloudDatacatalogV1TagTemplateFieldHttpRequest: ...
                    def delete(
                        self, *, name: str, force: bool = ..., **kwargs: typing.Any
                    ) -> EmptyHttpRequest: ...
                    def patch(
                        self,
                        *,
                        name: str,
                        body: GoogleCloudDatacatalogV1TagTemplateField = ...,
                        updateMask: str = ...,
                        **kwargs: typing.Any
                    ) -> GoogleCloudDatacatalogV1TagTemplateFieldHttpRequest: ...
                    def rename(
                        self,
                        *,
                        name: str,
                        body: GoogleCloudDatacatalogV1RenameTagTemplateFieldRequest = ...,
                        **kwargs: typing.Any
                    ) -> GoogleCloudDatacatalogV1TagTemplateFieldHttpRequest: ...
                    def enumValues(self) -> EnumValuesResource: ...

                def create(
                    self,
                    *,
                    parent: str,
                    body: GoogleCloudDatacatalogV1TagTemplate = ...,
                    tagTemplateId: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudDatacatalogV1TagTemplateHttpRequest: ...
                def delete(
                    self, *, name: str, force: bool = ..., **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleCloudDatacatalogV1TagTemplateHttpRequest: ...
                def getIamPolicy(
                    self,
                    *,
                    resource: str,
                    body: GetIamPolicyRequest = ...,
                    **kwargs: typing.Any
                ) -> PolicyHttpRequest: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: GoogleCloudDatacatalogV1TagTemplate = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudDatacatalogV1TagTemplateHttpRequest: ...
                def setIamPolicy(
                    self,
                    *,
                    resource: str,
                    body: SetIamPolicyRequest = ...,
                    **kwargs: typing.Any
                ) -> PolicyHttpRequest: ...
                def testIamPermissions(
                    self,
                    *,
                    resource: str,
                    body: TestIamPermissionsRequest = ...,
                    **kwargs: typing.Any
                ) -> TestIamPermissionsResponseHttpRequest: ...
                def fields(self) -> FieldsResource: ...

            @typing.type_check_only
            class TaxonomiesResource(googleapiclient.discovery.Resource):
                @typing.type_check_only
                class PolicyTagsResource(googleapiclient.discovery.Resource):
                    def create(
                        self,
                        *,
                        parent: str,
                        body: GoogleCloudDatacatalogV1PolicyTag = ...,
                        **kwargs: typing.Any
                    ) -> GoogleCloudDatacatalogV1PolicyTagHttpRequest: ...
                    def delete(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> EmptyHttpRequest: ...
                    def get(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> GoogleCloudDatacatalogV1PolicyTagHttpRequest: ...
                    def getIamPolicy(
                        self,
                        *,
                        resource: str,
                        body: GetIamPolicyRequest = ...,
                        **kwargs: typing.Any
                    ) -> PolicyHttpRequest: ...
                    def list(
                        self,
                        *,
                        parent: str,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        **kwargs: typing.Any
                    ) -> GoogleCloudDatacatalogV1ListPolicyTagsResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: GoogleCloudDatacatalogV1ListPolicyTagsResponseHttpRequest,
                        previous_response: GoogleCloudDatacatalogV1ListPolicyTagsResponse,
                    ) -> GoogleCloudDatacatalogV1ListPolicyTagsResponseHttpRequest | None: ...
                    def patch(
                        self,
                        *,
                        name: str,
                        body: GoogleCloudDatacatalogV1PolicyTag = ...,
                        updateMask: str = ...,
                        **kwargs: typing.Any
                    ) -> GoogleCloudDatacatalogV1PolicyTagHttpRequest: ...
                    def setIamPolicy(
                        self,
                        *,
                        resource: str,
                        body: SetIamPolicyRequest = ...,
                        **kwargs: typing.Any
                    ) -> PolicyHttpRequest: ...
                    def testIamPermissions(
                        self,
                        *,
                        resource: str,
                        body: TestIamPermissionsRequest = ...,
                        **kwargs: typing.Any
                    ) -> TestIamPermissionsResponseHttpRequest: ...

                def create(
                    self,
                    *,
                    parent: str,
                    body: GoogleCloudDatacatalogV1Taxonomy = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudDatacatalogV1TaxonomyHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def export(
                    self,
                    *,
                    parent: str,
                    serializedTaxonomies: bool = ...,
                    taxonomies: str | _list[str] = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudDatacatalogV1ExportTaxonomiesResponseHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleCloudDatacatalogV1TaxonomyHttpRequest: ...
                def getIamPolicy(
                    self,
                    *,
                    resource: str,
                    body: GetIamPolicyRequest = ...,
                    **kwargs: typing.Any
                ) -> PolicyHttpRequest: ...
                def import_(
                    self,
                    *,
                    parent: str,
                    body: GoogleCloudDatacatalogV1ImportTaxonomiesRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudDatacatalogV1ImportTaxonomiesResponseHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudDatacatalogV1ListTaxonomiesResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: GoogleCloudDatacatalogV1ListTaxonomiesResponseHttpRequest,
                    previous_response: GoogleCloudDatacatalogV1ListTaxonomiesResponse,
                ) -> GoogleCloudDatacatalogV1ListTaxonomiesResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: GoogleCloudDatacatalogV1Taxonomy = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudDatacatalogV1TaxonomyHttpRequest: ...
                def replace(
                    self,
                    *,
                    name: str,
                    body: GoogleCloudDatacatalogV1ReplaceTaxonomyRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudDatacatalogV1TaxonomyHttpRequest: ...
                def setIamPolicy(
                    self,
                    *,
                    resource: str,
                    body: SetIamPolicyRequest = ...,
                    **kwargs: typing.Any
                ) -> PolicyHttpRequest: ...
                def testIamPermissions(
                    self,
                    *,
                    resource: str,
                    body: TestIamPermissionsRequest = ...,
                    **kwargs: typing.Any
                ) -> TestIamPermissionsResponseHttpRequest: ...
                def policyTags(self) -> PolicyTagsResource: ...

            def entryGroups(self) -> EntryGroupsResource: ...
            def tagTemplates(self) -> TagTemplatesResource: ...
            def taxonomies(self) -> TaxonomiesResource: ...

        def locations(self) -> LocationsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def catalog(self) -> CatalogResource: ...
    def entries(self) -> EntriesResource: ...
    def projects(self) -> ProjectsResource: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class GoogleCloudDatacatalogV1ContactsHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudDatacatalogV1Contacts: ...

@typing.type_check_only
class GoogleCloudDatacatalogV1EntryHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudDatacatalogV1Entry: ...

@typing.type_check_only
class GoogleCloudDatacatalogV1EntryGroupHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudDatacatalogV1EntryGroup: ...

@typing.type_check_only
class GoogleCloudDatacatalogV1EntryOverviewHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudDatacatalogV1EntryOverview: ...

@typing.type_check_only
class GoogleCloudDatacatalogV1ExportTaxonomiesResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudDatacatalogV1ExportTaxonomiesResponse: ...

@typing.type_check_only
class GoogleCloudDatacatalogV1ImportTaxonomiesResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudDatacatalogV1ImportTaxonomiesResponse: ...

@typing.type_check_only
class GoogleCloudDatacatalogV1ListEntriesResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudDatacatalogV1ListEntriesResponse: ...

@typing.type_check_only
class GoogleCloudDatacatalogV1ListEntryGroupsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudDatacatalogV1ListEntryGroupsResponse: ...

@typing.type_check_only
class GoogleCloudDatacatalogV1ListPolicyTagsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudDatacatalogV1ListPolicyTagsResponse: ...

@typing.type_check_only
class GoogleCloudDatacatalogV1ListTagsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudDatacatalogV1ListTagsResponse: ...

@typing.type_check_only
class GoogleCloudDatacatalogV1ListTaxonomiesResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudDatacatalogV1ListTaxonomiesResponse: ...

@typing.type_check_only
class GoogleCloudDatacatalogV1PolicyTagHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudDatacatalogV1PolicyTag: ...

@typing.type_check_only
class GoogleCloudDatacatalogV1SearchCatalogResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudDatacatalogV1SearchCatalogResponse: ...

@typing.type_check_only
class GoogleCloudDatacatalogV1StarEntryResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudDatacatalogV1StarEntryResponse: ...

@typing.type_check_only
class GoogleCloudDatacatalogV1TagHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudDatacatalogV1Tag: ...

@typing.type_check_only
class GoogleCloudDatacatalogV1TagTemplateHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudDatacatalogV1TagTemplate: ...

@typing.type_check_only
class GoogleCloudDatacatalogV1TagTemplateFieldHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudDatacatalogV1TagTemplateField: ...

@typing.type_check_only
class GoogleCloudDatacatalogV1TaxonomyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudDatacatalogV1Taxonomy: ...

@typing.type_check_only
class GoogleCloudDatacatalogV1UnstarEntryResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudDatacatalogV1UnstarEntryResponse: ...

@typing.type_check_only
class PolicyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Policy: ...

@typing.type_check_only
class TestIamPermissionsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> TestIamPermissionsResponse: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class GoogleFirebaseAppcheckV1AppAttestConfig(typing_extensions.TypedDict, total=False):
    name: str
    tokenTtl: str

@typing.type_check_only
class GoogleFirebaseAppcheckV1AppCheckToken(typing_extensions.TypedDict, total=False):
    token: str
    ttl: str

@typing.type_check_only
class GoogleFirebaseAppcheckV1BatchGetAppAttestConfigsResponse(
    typing_extensions.TypedDict, total=False
):
    configs: _list[GoogleFirebaseAppcheckV1AppAttestConfig]

@typing.type_check_only
class GoogleFirebaseAppcheckV1BatchGetDeviceCheckConfigsResponse(
    typing_extensions.TypedDict, total=False
):
    configs: _list[GoogleFirebaseAppcheckV1DeviceCheckConfig]

@typing.type_check_only
class GoogleFirebaseAppcheckV1BatchGetPlayIntegrityConfigsResponse(
    typing_extensions.TypedDict, total=False
):
    configs: _list[GoogleFirebaseAppcheckV1PlayIntegrityConfig]

@typing.type_check_only
class GoogleFirebaseAppcheckV1BatchGetRecaptchaEnterpriseConfigsResponse(
    typing_extensions.TypedDict, total=False
):
    configs: _list[GoogleFirebaseAppcheckV1RecaptchaEnterpriseConfig]

@typing.type_check_only
class GoogleFirebaseAppcheckV1BatchGetRecaptchaV3ConfigsResponse(
    typing_extensions.TypedDict, total=False
):
    configs: _list[GoogleFirebaseAppcheckV1RecaptchaV3Config]

@typing.type_check_only
class GoogleFirebaseAppcheckV1BatchGetSafetyNetConfigsResponse(
    typing_extensions.TypedDict, total=False
):
    configs: _list[GoogleFirebaseAppcheckV1SafetyNetConfig]

@typing.type_check_only
class GoogleFirebaseAppcheckV1BatchUpdateServicesRequest(
    typing_extensions.TypedDict, total=False
):
    requests: _list[GoogleFirebaseAppcheckV1UpdateServiceRequest]
    updateMask: str

@typing.type_check_only
class GoogleFirebaseAppcheckV1BatchUpdateServicesResponse(
    typing_extensions.TypedDict, total=False
):
    services: _list[GoogleFirebaseAppcheckV1Service]

@typing.type_check_only
class GoogleFirebaseAppcheckV1DebugToken(typing_extensions.TypedDict, total=False):
    displayName: str
    name: str
    token: str

@typing.type_check_only
class GoogleFirebaseAppcheckV1DeviceCheckConfig(
    typing_extensions.TypedDict, total=False
):
    keyId: str
    name: str
    privateKey: str
    privateKeySet: bool
    tokenTtl: str

@typing.type_check_only
class GoogleFirebaseAppcheckV1ExchangeAppAttestAssertionRequest(
    typing_extensions.TypedDict, total=False
):
    artifact: str
    assertion: str
    challenge: str

@typing.type_check_only
class GoogleFirebaseAppcheckV1ExchangeAppAttestAttestationRequest(
    typing_extensions.TypedDict, total=False
):
    attestationStatement: str
    challenge: str
    keyId: str

@typing.type_check_only
class GoogleFirebaseAppcheckV1ExchangeAppAttestAttestationResponse(
    typing_extensions.TypedDict, total=False
):
    appCheckToken: GoogleFirebaseAppcheckV1AppCheckToken
    artifact: str

@typing.type_check_only
class GoogleFirebaseAppcheckV1ExchangeCustomTokenRequest(
    typing_extensions.TypedDict, total=False
):
    customToken: str

@typing.type_check_only
class GoogleFirebaseAppcheckV1ExchangeDebugTokenRequest(
    typing_extensions.TypedDict, total=False
):
    debugToken: str

@typing.type_check_only
class GoogleFirebaseAppcheckV1ExchangeDeviceCheckTokenRequest(
    typing_extensions.TypedDict, total=False
):
    deviceToken: str

@typing.type_check_only
class GoogleFirebaseAppcheckV1ExchangePlayIntegrityTokenRequest(
    typing_extensions.TypedDict, total=False
):
    playIntegrityToken: str

@typing.type_check_only
class GoogleFirebaseAppcheckV1ExchangeRecaptchaEnterpriseTokenRequest(
    typing_extensions.TypedDict, total=False
):
    recaptchaEnterpriseToken: str

@typing.type_check_only
class GoogleFirebaseAppcheckV1ExchangeRecaptchaV3TokenRequest(
    typing_extensions.TypedDict, total=False
):
    recaptchaV3Token: str

@typing.type_check_only
class GoogleFirebaseAppcheckV1ExchangeSafetyNetTokenRequest(
    typing_extensions.TypedDict, total=False
):
    safetyNetToken: str

@typing.type_check_only
class GoogleFirebaseAppcheckV1GenerateAppAttestChallengeRequest(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleFirebaseAppcheckV1GenerateAppAttestChallengeResponse(
    typing_extensions.TypedDict, total=False
):
    challenge: str
    ttl: str

@typing.type_check_only
class GoogleFirebaseAppcheckV1GeneratePlayIntegrityChallengeRequest(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleFirebaseAppcheckV1GeneratePlayIntegrityChallengeResponse(
    typing_extensions.TypedDict, total=False
):
    challenge: str
    ttl: str

@typing.type_check_only
class GoogleFirebaseAppcheckV1ListDebugTokensResponse(
    typing_extensions.TypedDict, total=False
):
    debugTokens: _list[GoogleFirebaseAppcheckV1DebugToken]
    nextPageToken: str

@typing.type_check_only
class GoogleFirebaseAppcheckV1ListServicesResponse(
    typing_extensions.TypedDict, total=False
):
    nextPageToken: str
    services: _list[GoogleFirebaseAppcheckV1Service]

@typing.type_check_only
class GoogleFirebaseAppcheckV1PlayIntegrityConfig(
    typing_extensions.TypedDict, total=False
):
    name: str
    tokenTtl: str

@typing.type_check_only
class GoogleFirebaseAppcheckV1PublicJwk(typing_extensions.TypedDict, total=False):
    alg: str
    e: str
    kid: str
    kty: str
    n: str
    use: str

@typing.type_check_only
class GoogleFirebaseAppcheckV1PublicJwkSet(typing_extensions.TypedDict, total=False):
    keys: _list[GoogleFirebaseAppcheckV1PublicJwk]

@typing.type_check_only
class GoogleFirebaseAppcheckV1RecaptchaEnterpriseConfig(
    typing_extensions.TypedDict, total=False
):
    name: str
    siteKey: str
    tokenTtl: str

@typing.type_check_only
class GoogleFirebaseAppcheckV1RecaptchaV3Config(
    typing_extensions.TypedDict, total=False
):
    name: str
    siteSecret: str
    siteSecretSet: bool
    tokenTtl: str

@typing.type_check_only
class GoogleFirebaseAppcheckV1SafetyNetConfig(typing_extensions.TypedDict, total=False):
    name: str
    tokenTtl: str

@typing.type_check_only
class GoogleFirebaseAppcheckV1Service(typing_extensions.TypedDict, total=False):
    enforcementMode: typing_extensions.Literal["OFF", "UNENFORCED", "ENFORCED"]
    name: str

@typing.type_check_only
class GoogleFirebaseAppcheckV1UpdateServiceRequest(
    typing_extensions.TypedDict, total=False
):
    service: GoogleFirebaseAppcheckV1Service
    updateMask: str

@typing.type_check_only
class GoogleProtobufEmpty(typing_extensions.TypedDict, total=False): ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class IamResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class IamPoliciesResource(googleapiclient.discovery.Resource):
        def lintPolicy(
            self, *, body: LintPolicyRequest = ..., **kwargs: typing.Any
        ) -> LintPolicyResponseHttpRequest: ...
        def queryAuditableServices(
            self, *, body: QueryAuditableServicesRequest = ..., **kwargs: typing.Any
        ) -> QueryAuditableServicesResponseHttpRequest: ...

    @typing.type_check_only
    class LocationsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class WorkforcePoolsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class OperationsResource(googleapiclient.discovery.Resource):
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> OperationHttpRequest: ...

            @typing.type_check_only
            class ProvidersResource(googleapiclient.discovery.Resource):
                @typing.type_check_only
                class KeysResource(googleapiclient.discovery.Resource):
                    @typing.type_check_only
                    class OperationsResource(googleapiclient.discovery.Resource):
                        def get(
                            self, *, name: str, **kwargs: typing.Any
                        ) -> OperationHttpRequest: ...

                    def operations(self) -> OperationsResource: ...

                @typing.type_check_only
                class OperationsResource(googleapiclient.discovery.Resource):
                    def get(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...

                def keys(self) -> KeysResource: ...
                def operations(self) -> OperationsResource: ...

            @typing.type_check_only
            class SubjectsResource(googleapiclient.discovery.Resource):
                @typing.type_check_only
                class OperationsResource(googleapiclient.discovery.Resource):
                    def get(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...

                def operations(self) -> OperationsResource: ...

            def operations(self) -> OperationsResource: ...
            def providers(self) -> ProvidersResource: ...
            def subjects(self) -> SubjectsResource: ...

        def workforcePools(self) -> WorkforcePoolsResource: ...

    @typing.type_check_only
    class OrganizationsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class RolesResource(googleapiclient.discovery.Resource):
            def create(
                self,
                *,
                parent: str,
                body: CreateRoleRequest = ...,
                **kwargs: typing.Any
            ) -> RoleHttpRequest: ...
            def delete(
                self, *, name: str, etag: str = ..., **kwargs: typing.Any
            ) -> RoleHttpRequest: ...
            def get(self, *, name: str, **kwargs: typing.Any) -> RoleHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                pageSize: int = ...,
                pageToken: str = ...,
                showDeleted: bool = ...,
                view: typing_extensions.Literal["BASIC", "FULL"] = ...,
                **kwargs: typing.Any
            ) -> ListRolesResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListRolesResponseHttpRequest,
                previous_response: ListRolesResponse,
            ) -> ListRolesResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                name: str,
                body: Role = ...,
                updateMask: str = ...,
                **kwargs: typing.Any
            ) -> RoleHttpRequest: ...
            def undelete(
                self,
                *,
                name: str,
                body: UndeleteRoleRequest = ...,
                **kwargs: typing.Any
            ) -> RoleHttpRequest: ...

        def roles(self) -> RolesResource: ...

    @typing.type_check_only
    class PermissionsResource(googleapiclient.discovery.Resource):
        def queryTestablePermissions(
            self, *, body: QueryTestablePermissionsRequest = ..., **kwargs: typing.Any
        ) -> QueryTestablePermissionsResponseHttpRequest: ...
        def queryTestablePermissions_next(
            self,
            previous_request: QueryTestablePermissionsResponseHttpRequest,
            previous_response: QueryTestablePermissionsResponse,
        ) -> QueryTestablePermissionsResponseHttpRequest | None: ...

    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class LocationsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class WorkloadIdentityPoolsResource(googleapiclient.discovery.Resource):
                @typing.type_check_only
                class OperationsResource(googleapiclient.discovery.Resource):
                    def get(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...

                @typing.type_check_only
                class ProvidersResource(googleapiclient.discovery.Resource):
                    @typing.type_check_only
                    class KeysResource(googleapiclient.discovery.Resource):
                        @typing.type_check_only
                        class OperationsResource(googleapiclient.discovery.Resource):
                            def get(
                                self, *, name: str, **kwargs: typing.Any
                            ) -> OperationHttpRequest: ...

                        def operations(self) -> OperationsResource: ...

                    @typing.type_check_only
                    class OperationsResource(googleapiclient.discovery.Resource):
                        def get(
                            self, *, name: str, **kwargs: typing.Any
                        ) -> OperationHttpRequest: ...

                    def create(
                        self,
                        *,
                        parent: str,
                        body: WorkloadIdentityPoolProvider = ...,
                        workloadIdentityPoolProviderId: str = ...,
                        **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...
                    def delete(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...
                    def get(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> WorkloadIdentityPoolProviderHttpRequest: ...
                    def list(
                        self,
                        *,
                        parent: str,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        showDeleted: bool = ...,
                        **kwargs: typing.Any
                    ) -> ListWorkloadIdentityPoolProvidersResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: ListWorkloadIdentityPoolProvidersResponseHttpRequest,
                        previous_response: ListWorkloadIdentityPoolProvidersResponse,
                    ) -> ListWorkloadIdentityPoolProvidersResponseHttpRequest | None: ...
                    def patch(
                        self,
                        *,
                        name: str,
                        body: WorkloadIdentityPoolProvider = ...,
                        updateMask: str = ...,
                        **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...
                    def undelete(
                        self,
                        *,
                        name: str,
                        body: UndeleteWorkloadIdentityPoolProviderRequest = ...,
                        **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...
                    def keys(self) -> KeysResource: ...
                    def operations(self) -> OperationsResource: ...

                def create(
                    self,
                    *,
                    parent: str,
                    body: WorkloadIdentityPool = ...,
                    workloadIdentityPoolId: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> WorkloadIdentityPoolHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    showDeleted: bool = ...,
                    **kwargs: typing.Any
                ) -> ListWorkloadIdentityPoolsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListWorkloadIdentityPoolsResponseHttpRequest,
                    previous_response: ListWorkloadIdentityPoolsResponse,
                ) -> ListWorkloadIdentityPoolsResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: WorkloadIdentityPool = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def undelete(
                    self,
                    *,
                    name: str,
                    body: UndeleteWorkloadIdentityPoolRequest = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def operations(self) -> OperationsResource: ...
                def providers(self) -> ProvidersResource: ...

            def workloadIdentityPools(self) -> WorkloadIdentityPoolsResource: ...

        @typing.type_check_only
        class RolesResource(googleapiclient.discovery.Resource):
            def create(
                self,
                *,
                parent: str,
                body: CreateRoleRequest = ...,
                **kwargs: typing.Any
            ) -> RoleHttpRequest: ...
            def delete(
                self, *, name: str, etag: str = ..., **kwargs: typing.Any
            ) -> RoleHttpRequest: ...
            def get(self, *, name: str, **kwargs: typing.Any) -> RoleHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                pageSize: int = ...,
                pageToken: str = ...,
                showDeleted: bool = ...,
                view: typing_extensions.Literal["BASIC", "FULL"] = ...,
                **kwargs: typing.Any
            ) -> ListRolesResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListRolesResponseHttpRequest,
                previous_response: ListRolesResponse,
            ) -> ListRolesResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                name: str,
                body: Role = ...,
                updateMask: str = ...,
                **kwargs: typing.Any
            ) -> RoleHttpRequest: ...
            def undelete(
                self,
                *,
                name: str,
                body: UndeleteRoleRequest = ...,
                **kwargs: typing.Any
            ) -> RoleHttpRequest: ...

        @typing.type_check_only
        class ServiceAccountsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class KeysResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    name: str,
                    body: CreateServiceAccountKeyRequest = ...,
                    **kwargs: typing.Any
                ) -> ServiceAccountKeyHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def disable(
                    self,
                    *,
                    name: str,
                    body: DisableServiceAccountKeyRequest = ...,
                    **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def enable(
                    self,
                    *,
                    name: str,
                    body: EnableServiceAccountKeyRequest = ...,
                    **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def get(
                    self,
                    *,
                    name: str,
                    publicKeyType: typing_extensions.Literal[
                        "TYPE_NONE", "TYPE_X509_PEM_FILE", "TYPE_RAW_PUBLIC_KEY"
                    ] = ...,
                    **kwargs: typing.Any
                ) -> ServiceAccountKeyHttpRequest: ...
                def list(
                    self,
                    *,
                    name: str,
                    keyTypes: typing_extensions.Literal[
                        "KEY_TYPE_UNSPECIFIED", "USER_MANAGED", "SYSTEM_MANAGED"
                    ]
                    | _list[
                        typing_extensions.Literal[
                            "KEY_TYPE_UNSPECIFIED", "USER_MANAGED", "SYSTEM_MANAGED"
                        ]
                    ] = ...,
                    **kwargs: typing.Any
                ) -> ListServiceAccountKeysResponseHttpRequest: ...
                def upload(
                    self,
                    *,
                    name: str,
                    body: UploadServiceAccountKeyRequest = ...,
                    **kwargs: typing.Any
                ) -> ServiceAccountKeyHttpRequest: ...

            def create(
                self,
                *,
                name: str,
                body: CreateServiceAccountRequest = ...,
                **kwargs: typing.Any
            ) -> ServiceAccountHttpRequest: ...
            def delete(
                self, *, name: str, **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def disable(
                self,
                *,
                name: str,
                body: DisableServiceAccountRequest = ...,
                **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def enable(
                self,
                *,
                name: str,
                body: EnableServiceAccountRequest = ...,
                **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> ServiceAccountHttpRequest: ...
            def getIamPolicy(
                self,
                *,
                resource: str,
                options_requestedPolicyVersion: int = ...,
                **kwargs: typing.Any
            ) -> PolicyHttpRequest: ...
            def list(
                self,
                *,
                name: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListServiceAccountsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListServiceAccountsResponseHttpRequest,
                previous_response: ListServiceAccountsResponse,
            ) -> ListServiceAccountsResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                name: str,
                body: PatchServiceAccountRequest = ...,
                **kwargs: typing.Any
            ) -> ServiceAccountHttpRequest: ...
            def setIamPolicy(
                self,
                *,
                resource: str,
                body: SetIamPolicyRequest = ...,
                **kwargs: typing.Any
            ) -> PolicyHttpRequest: ...
            def signBlob(
                self, *, name: str, body: SignBlobRequest = ..., **kwargs: typing.Any
            ) -> SignBlobResponseHttpRequest: ...
            def signJwt(
                self, *, name: str, body: SignJwtRequest = ..., **kwargs: typing.Any
            ) -> SignJwtResponseHttpRequest: ...
            def testIamPermissions(
                self,
                *,
                resource: str,
                body: TestIamPermissionsRequest = ...,
                **kwargs: typing.Any
            ) -> TestIamPermissionsResponseHttpRequest: ...
            def undelete(
                self,
                *,
                name: str,
                body: UndeleteServiceAccountRequest = ...,
                **kwargs: typing.Any
            ) -> UndeleteServiceAccountResponseHttpRequest: ...
            def update(
                self, *, name: str, body: ServiceAccount = ..., **kwargs: typing.Any
            ) -> ServiceAccountHttpRequest: ...
            def keys(self) -> KeysResource: ...

        def locations(self) -> LocationsResource: ...
        def roles(self) -> RolesResource: ...
        def serviceAccounts(self) -> ServiceAccountsResource: ...

    @typing.type_check_only
    class RolesResource(googleapiclient.discovery.Resource):
        def get(self, *, name: str, **kwargs: typing.Any) -> RoleHttpRequest: ...
        def list(
            self,
            *,
            pageSize: int = ...,
            pageToken: str = ...,
            parent: str = ...,
            showDeleted: bool = ...,
            view: typing_extensions.Literal["BASIC", "FULL"] = ...,
            **kwargs: typing.Any
        ) -> ListRolesResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: ListRolesResponseHttpRequest,
            previous_response: ListRolesResponse,
        ) -> ListRolesResponseHttpRequest | None: ...
        def queryGrantableRoles(
            self, *, body: QueryGrantableRolesRequest = ..., **kwargs: typing.Any
        ) -> QueryGrantableRolesResponseHttpRequest: ...
        def queryGrantableRoles_next(
            self,
            previous_request: QueryGrantableRolesResponseHttpRequest,
            previous_response: QueryGrantableRolesResponse,
        ) -> QueryGrantableRolesResponseHttpRequest | None: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def iamPolicies(self) -> IamPoliciesResource: ...
    def locations(self) -> LocationsResource: ...
    def organizations(self) -> OrganizationsResource: ...
    def permissions(self) -> PermissionsResource: ...
    def projects(self) -> ProjectsResource: ...
    def roles(self) -> RolesResource: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class LintPolicyResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> LintPolicyResponse: ...

@typing.type_check_only
class ListRolesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListRolesResponse: ...

@typing.type_check_only
class ListServiceAccountKeysResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListServiceAccountKeysResponse: ...

@typing.type_check_only
class ListServiceAccountsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListServiceAccountsResponse: ...

@typing.type_check_only
class ListWorkloadIdentityPoolProvidersResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListWorkloadIdentityPoolProvidersResponse: ...

@typing.type_check_only
class ListWorkloadIdentityPoolsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListWorkloadIdentityPoolsResponse: ...

@typing.type_check_only
class OperationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Operation: ...

@typing.type_check_only
class PolicyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Policy: ...

@typing.type_check_only
class QueryAuditableServicesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> QueryAuditableServicesResponse: ...

@typing.type_check_only
class QueryGrantableRolesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> QueryGrantableRolesResponse: ...

@typing.type_check_only
class QueryTestablePermissionsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> QueryTestablePermissionsResponse: ...

@typing.type_check_only
class RoleHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Role: ...

@typing.type_check_only
class ServiceAccountHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ServiceAccount: ...

@typing.type_check_only
class ServiceAccountKeyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ServiceAccountKey: ...

@typing.type_check_only
class SignBlobResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SignBlobResponse: ...

@typing.type_check_only
class SignJwtResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SignJwtResponse: ...

@typing.type_check_only
class TestIamPermissionsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> TestIamPermissionsResponse: ...

@typing.type_check_only
class UndeleteServiceAccountResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> UndeleteServiceAccountResponse: ...

@typing.type_check_only
class WorkloadIdentityPoolHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> WorkloadIdentityPool: ...

@typing.type_check_only
class WorkloadIdentityPoolProviderHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> WorkloadIdentityPoolProvider: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class FirebaseMLResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class ModelsResource(googleapiclient.discovery.Resource):
            def create(
                self, *, parent: str, body: Model = ..., **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def delete(
                self, *, name: str, **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def download(
                self, *, name: str, **kwargs: typing.Any
            ) -> DownloadModelResponseHttpRequest: ...
            def get(self, *, name: str, **kwargs: typing.Any) -> ModelHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                filter: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListModelsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListModelsResponseHttpRequest,
                previous_response: ListModelsResponse,
            ) -> ListModelsResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                name: str,
                body: Model = ...,
                updateMask: str = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...

        @typing.type_check_only
        class OperationsResource(googleapiclient.discovery.Resource):
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> OperationHttpRequest: ...

        def models(self) -> ModelsResource: ...
        def operations(self) -> OperationsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def projects(self) -> ProjectsResource: ...

@typing.type_check_only
class DownloadModelResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> DownloadModelResponse: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class ListModelsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListModelsResponse: ...

@typing.type_check_only
class ModelHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Model: ...

@typing.type_check_only
class OperationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Operation: ...
